(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[      8880,        253]
NotebookOptionsPosition[      8298,        229]
NotebookOutlinePosition[      8719,        246]
CellTagsIndexPosition[      8676,        243]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Damped Harmonic Oscillator", "Section",
 CellChangeTimes->{{3.6612929403808117`*^9, 3.661292955394588*^9}}],

Cell["\<\
The amplitude and phase response of a damped harmonic oscillator\
\>", "Text",
 CellChangeTimes->{{3.661293234835722*^9, 3.6612932503873262`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eqm", "=", 
  RowBox[{"1", "/", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"w", "^", "2"}], "-", 
        RowBox[{"w0", "^", "2"}]}], ")"}], "^", "2"}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"lam", "^", "2"}], " ", 
      RowBox[{"w", "^", "2"}]}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"eqp", "=", 
  RowBox[{"ArcTan", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"w", "^", "2"}], "-", 
       RowBox[{"w0", "^", "2"}]}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"-", "2"}], " ", "lam", " ", "w"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pp", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}], ",", 
     RowBox[{"ImageSize", "->", "Medium"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"eqm", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"w0", "\[Rule]", "1"}], ",", 
             RowBox[{"lam", "\[Rule]", 
              RowBox[{"10", "^", "llambda"}]}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"w", ",", "0.1", ",", "10"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", " ", 
          RowBox[{"Evaluate", "[", "pp", "]"}]}], "]"}], ",", 
        RowBox[{"LogLogPlot", "[", 
         RowBox[{
          RowBox[{"eqm", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"w0", "\[Rule]", "1"}], ",", 
             RowBox[{"lam", "\[Rule]", 
              RowBox[{"10", "^", "llambda"}]}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"w", ",", "0.1", ",", "10"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", " ", 
          RowBox[{"Evaluate", "[", "pp", "]"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"eqp", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"w0", "\[Rule]", "1"}], ",", 
             RowBox[{"lam", "\[Rule]", 
              RowBox[{"10", "^", "llambda"}]}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"w", ",", "0.1", ",", "10"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", " ", 
          RowBox[{"Evaluate", "[", "pp", "]"}]}], "]"}], ",", 
        RowBox[{"LogLinearPlot", "[", 
         RowBox[{
          RowBox[{"eqp", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"w0", "\[Rule]", "1"}], ",", 
             RowBox[{"lam", "\[Rule]", 
              RowBox[{"10", "^", "llambda"}]}]}], "}"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"w", ",", "0.1", ",", "10"}], "}"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", " ", 
          RowBox[{"Evaluate", "[", "pp", "]"}]}], "]"}]}], "}"}]}], "}"}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"llambda", ",", 
       RowBox[{"-", "1"}], ",", " ", "\"\<Log10 \[Lambda]\>\""}], "}"}], ",", 
     
     RowBox[{"-", "2"}], ",", "0", ",", "0.1"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.661280663636284*^9, 3.6612809262020283`*^9}, {
  3.661284292684169*^9, 3.661284333999765*^9}, {3.6612843804017267`*^9, 
  3.661284492145266*^9}, {3.661284557051515*^9, 3.661284560207204*^9}, {
  3.661284622121467*^9, 3.6612846309057617`*^9}, {3.6612910308787127`*^9, 
  3.661291041732953*^9}, {3.6612912410238247`*^9, 3.6612913514449577`*^9}, {
  3.6612913847291183`*^9, 3.661291405582178*^9}, {3.6612914394879503`*^9, 
  3.6612915407206793`*^9}, {3.66129158333365*^9, 3.6612916485483303`*^9}, {
  3.66129179365865*^9, 3.661291849312345*^9}, {3.6612925505918207`*^9, 
  3.6612925897917233`*^9}, {3.6612926260072002`*^9, 3.6612926767178183`*^9}, {
  3.661292745155612*^9, 3.661292758377892*^9}}],

Cell[BoxData[
 FractionBox["1", 
  SqrtBox[
   RowBox[{
    RowBox[{"4", " ", 
     SuperscriptBox["lam", "2"], " ", 
     SuperscriptBox["w", "2"]}], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["w", "2"], "-", 
       SuperscriptBox["w0", "2"]}], ")"}], "2"]}]]]], "Output",
 CellChangeTimes->{3.661292893741289*^9}],

Cell[BoxData[
 RowBox[{"ArcTan", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["w", "2"]}], "+", 
    SuperscriptBox["w0", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", "lam", " ", "w"}]}], "]"}]], "Output",
 CellChangeTimes->{3.661292893742414*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`llambda$$ = -1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`llambda$$], -1, "Log10 \[Lambda]"}, -2, 0, 0.1}}, 
    Typeset`size$$ = {780., {241., 246.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`llambda$130783$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`llambda$$ = -1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`llambda$$, $CellContext`llambda$130783$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> GraphicsGrid[{{
          Plot[
           
           ReplaceAll[$CellContext`eqm, {$CellContext`w0 -> 
             1, $CellContext`lam -> 
             10^$CellContext`llambda$$}], {$CellContext`w, 0.1, 10}, 
           PlotRange -> Full, 
           Evaluate[$CellContext`pp]], 
          LogLogPlot[
           
           ReplaceAll[$CellContext`eqm, {$CellContext`w0 -> 
             1, $CellContext`lam -> 
             10^$CellContext`llambda$$}], {$CellContext`w, 0.1, 10}, 
           PlotRange -> Full, 
           Evaluate[$CellContext`pp]]}, {
          Plot[
           
           ReplaceAll[$CellContext`eqp, {$CellContext`w0 -> 
             1, $CellContext`lam -> 
             10^$CellContext`llambda$$}], {$CellContext`w, 0.1, 10}, 
           PlotRange -> Full, 
           Evaluate[$CellContext`pp]], 
          LogLinearPlot[
           
           ReplaceAll[$CellContext`eqp, {$CellContext`w0 -> 
             1, $CellContext`lam -> 
             10^$CellContext`llambda$$}], {$CellContext`w, 0.1, 10}, 
           PlotRange -> Full, 
           Evaluate[$CellContext`pp]]}}], 
      "Specifications" :> {{{$CellContext`llambda$$, -1, 
          "Log10 \[Lambda]"}, -2, 0, 0.1}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{829., {290., 299.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.661292893756185*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1223, 756},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (June 27, \
2014)",
StyleDefinitions->FrontEnd`FileName[{"SlideShow"}, "Sapphire.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 113, 1, 120, "Section"],
Cell[696, 25, 156, 3, 59, "Text"],
Cell[CellGroupData[{
Cell[877, 32, 4065, 105, 294, "Input"],
Cell[4945, 139, 355, 12, 108, "Output"],
Cell[5303, 153, 279, 9, 50, "Output"],
Cell[5585, 164, 2685, 61, 613, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
