(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    411260,       7454]
NotebookOptionsPosition[    408344,       7357]
NotebookOutlinePosition[    408766,       7374]
CellTagsIndexPosition[    408723,       7371]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["The Driven Pendulum", "Section",
 CellChangeTimes->{{3.660832414776634*^9, 3.66083244909306*^9}, {
  3.66119258412182*^9, 3.661192589991214*^9}}],

Cell[CellGroupData[{

Cell["Solving the Lagrangian", "Subsection",
 CellChangeTimes->{{3.661192087423953*^9, 3.661192093013431*^9}}],

Cell[TextData[{
 "Setup the problem with Potential Energy (U) and Kinetic Energy (T)\nThe \
pendulum suport point moves as a function of time, ",
 StyleBox["xd[t]", "Input"],
 ".  The coordinates of the pendulum mass are ",
 StyleBox["xm", "Input"],
 " and ",
 StyleBox["ym.", "Input"]
}], "Text",
 CellChangeTimes->{{3.661192131929822*^9, 3.661192162037263*^9}, {
  3.661192605026491*^9, 3.661192638925995*^9}, {3.661195314020802*^9, 
  3.6611953630472937`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"xm", "[", "t", "]"}], "=", 
   RowBox[{
    RowBox[{"xd", "[", "t", "]"}], "+", 
    RowBox[{"l", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ym", "[", "t", "]"}], "=", 
   RowBox[{"l", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"phi", "[", "t", "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"U", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"-", "m"}], " ", "g", " ", 
    RowBox[{"ym", "[", "t", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"T", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], " ", "m", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"xm", "[", "t", "]"}], ",", "t"}], "]"}], "^", "2"}], "+", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"ym", "[", "t", "]"}], ",", "t"}], "]"}], "^", "2"}]}], 
     ")"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6611921105715637`*^9, 3.661192123943734*^9}, 
   3.661192177209876*^9, {3.6611922593162317`*^9, 3.6611922883056602`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "g"}], " ", "l", " ", "m", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"phi", "[", "t", "]"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.661192279740629*^9, 3.661192288568173*^9}, 
   3.661192656179741*^9, 3.66119295489567*^9, {3.6611931724627323`*^9, 
   3.6611932413045883`*^9}, 3.661194326805313*^9, 3.6611953743912983`*^9, 
   3.662200533325944*^9, 3.6942003335693693`*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "m", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["l", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["phi", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"2", " ", "l", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["phi", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["xd", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["xd", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.661192279740629*^9, 3.661192288568173*^9}, 
   3.661192656179741*^9, 3.66119295489567*^9, {3.6611931724627323`*^9, 
   3.6611932413045883`*^9}, 3.661194326805313*^9, 3.6611953743912983`*^9, 
   3.662200533325944*^9, 3.694200333640566*^9}]
}, Open  ]],

Cell["Solve the Euler-Lagrange Equation", "Text",
 CellChangeTimes->{{3.661192190740988*^9, 3.6611921970584297`*^9}, {
  3.661192233753406*^9, 3.661192234897395*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Fphi", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"T", "-", "U"}], ",", 
     RowBox[{"phi", "[", "t", "]"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"pphi", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"T", "-", "U"}], ",", 
     RowBox[{
      RowBox[{"phi", "'"}], "[", "t", "]"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"dpphi", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"pphi", ",", "t"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"eomd", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Fphi", "\[Equal]", "dpphi"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"m", ">", "0"}], ",", 
       RowBox[{"l", ">", "0"}]}], "}"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{
  3.661192250685864*^9, {3.661192340977541*^9, 3.6611923470237007`*^9}, {
   3.661192908649427*^9, 3.661192930895393*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "l"}], " ", "m", " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
  RowBox[{"(", 
   RowBox[{"g", "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["phi", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["xd", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.6611923510298557`*^9, 3.66119265640351*^9, 3.661192955152038*^9, {
   3.6611931727785892`*^9, 3.661193241575959*^9}, 3.6611943271038218`*^9, 
   3.661195374767346*^9, 3.662200533515121*^9, 3.694200333787861*^9}],

Cell[BoxData[
 RowBox[{"l", " ", "m", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"l", " ", 
     RowBox[{
      SuperscriptBox["phi", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["xd", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.6611923510298557`*^9, 3.66119265640351*^9, 3.661192955152038*^9, {
   3.6611931727785892`*^9, 3.661193241575959*^9}, 3.6611943271038218`*^9, 
   3.661195374767346*^9, 3.662200533515121*^9, 3.694200333800252*^9}],

Cell[BoxData[
 RowBox[{"l", " ", "m", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sin", "[", 
       RowBox[{"phi", "[", "t", "]"}], "]"}]}], " ", 
     RowBox[{
      SuperscriptBox["phi", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["xd", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"l", " ", 
     RowBox[{
      SuperscriptBox["phi", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["xd", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.6611923510298557`*^9, 3.66119265640351*^9, 3.661192955152038*^9, {
   3.6611931727785892`*^9, 3.661193241575959*^9}, 3.6611943271038218`*^9, 
   3.661195374767346*^9, 3.662200533515121*^9, 3.6942003338139353`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"g", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"phi", "[", "t", "]"}], "]"}]}], "+", 
   RowBox[{"l", " ", 
    RowBox[{
     SuperscriptBox["phi", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "+", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["xd", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{
  3.6611923510298557`*^9, 3.66119265640351*^9, 3.661192955152038*^9, {
   3.6611931727785892`*^9, 3.661193241575959*^9}, 3.6611943271038218`*^9, 
   3.661195374767346*^9, 3.662200533515121*^9, 3.69420033387276*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solve the Equations of Motion:
Low frequency drive - superposition\
\>", "Subsection",
 CellChangeTimes->{{3.661192395534131*^9, 3.661192407388399*^9}, {
  3.6611928211387577`*^9, 3.6611928371361322`*^9}, {3.66119493146782*^9, 
  3.6611949345478277`*^9}, {3.694200959079536*^9, 3.694200959997919*^9}}],

Cell["List dependent variables", "Text",
 CellChangeTimes->{{3.660832456879169*^9, 3.6608324600056953`*^9}, {
  3.660832835692389*^9, 3.6608328397141047`*^9}, {3.661192066297888*^9, 
  3.6611920689822903`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dvars", "=", 
   RowBox[{"{", "phi", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.660832483703415*^9, 3.660832584660935*^9}, 
   3.660832764596962*^9, {3.6608328603805437`*^9, 3.660832875412587*^9}}],

Cell["Set initial condisions and drive function", "Text",
 CellChangeTimes->{{3.660832681260478*^9, 3.660832687766308*^9}, {
  3.6611930032855873`*^9, 3.661193061977792*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"incon", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"phi", "[", "0", "]"}], "\[Equal]", "phi0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"phi", "'"}], "[", "0", "]"}], "\[Equal]", "v0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"x1", "[", "t", "]"}], "=", 
   RowBox[{"ad", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"fd", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"g", "/", "l"}], "]"}], " ", "t"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eom", "=", 
   RowBox[{"eomd", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"xd", "''"}], "[", "t", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"x1", "[", "t", "]"}], ",", "t"}], "]"}], ",", "t"}], 
       "]"}]}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6608326954929867`*^9, 3.660832751006125*^9}, {
  3.661193056669105*^9, 3.661193057100478*^9}, {3.66119312046727*^9, 
  3.66119314712897*^9}, {3.661193235464512*^9, 3.661193236134149*^9}}],

Cell["\<\
Define all parameters:
g = gravity
l = length of pendulum
ad = drive amplitude
fd = drive frequency / pendulum resonant frequency
phi0 = phi at t = 0 = initial angle from vertical
v0 = dphi/dt at t = 0 = initial angular velocity\
\>", "Text",
 CellChangeTimes->{{3.660832915122074*^9, 3.660832921143371*^9}, {
  3.694200543093598*^9, 3.694200711275011*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"g", "\[Rule]", 
      RowBox[{"\[Pi]", "^", "2"}]}], ",", 
     RowBox[{"l", "\[Rule]", "1"}], ",", 
     RowBox[{"ad", "\[Rule]", "0.1"}], ",", 
     RowBox[{"fd", "\[Rule]", "0.1"}], ",", 
     RowBox[{"phi0", "\[Rule]", "0"}], ",", 
     RowBox[{"v0", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{
    RowBox[{"30", " ", "2", 
     RowBox[{"\[Pi]", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"g", "/", "l"}], "]"}]}]}], "/.", "pars"}]}], ";"}]}], "Input",\

 CellChangeTimes->{{3.660832934883301*^9, 3.6608329811674843`*^9}, {
   3.66083518203434*^9, 3.660835186864388*^9}, {3.6611924588876343`*^9, 
   3.6611924687916613`*^9}, {3.661192715248855*^9, 3.6611927435998173`*^9}, {
   3.661192902039855*^9, 3.6611929408869123`*^9}, {3.661193088336308*^9, 
   3.661193090829599*^9}, {3.661193152562392*^9, 3.661193214374984*^9}, {
   3.661194304467681*^9, 3.661194316351289*^9}, {3.69420081488055*^9, 
   3.6942008165421886`*^9}, {3.694200890360409*^9, 3.694200914703861*^9}, {
   3.694200944930258*^9, 3.69420094872779*^9}, 3.694200990095653*^9, {
   3.69420121155851*^9, 3.6942012160557528`*^9}}],

Cell[TextData[{
 "Solve with NDSolve:\nTry different values of ",
 StyleBox["fd", "Input"],
 " all less than 1..."
}], "Text",
 CellChangeTimes->{{3.660832600511394*^9, 3.66083260568856*^9}, {
  3.694200754631919*^9, 3.694200760694297*^9}, {3.694200879028867*^9, 
  3.6942009095577717`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eom", ",", "incon"}], "}"}], "//.", "pars"}], ",", "dvars", 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
    RowBox[{"MaxStepSize", "\[Rule]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"10", " ", "fd"}], ")"}]}], "/.", "pars"}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.660832619090395*^9, 3.660832660968112*^9}, {
   3.660832800013995*^9, 3.660832815099805*^9}, {3.660832885950898*^9, 
   3.660832895810577*^9}, {3.660832987215814*^9, 3.660832999807445*^9}, {
   3.660835197920516*^9, 3.660835198731563*^9}, 3.661192505638955*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"phi", "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["InterpolatingFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA9xwHa8MPsT4AAAAAtQLZO4Q91Tyl
TO8/YzcYecWRMz+t8DvJ0E4AQLu8/t6XYEM/dW6N1I46CEBOevRU3T9LP1BO
KyeG/g9AwNVjGpF7Tz+3TYwWfjUUQFqTqwuY0VA/g2IoYsQjGEAiAuYnBQBP
P/EtbAdKZhxAZcO9zqItSz80FSsodkogQGDlC/7Ov0A/j8ry8Mw9IkBsEiwr
xII0PztbjmZDWyRAee6/GyfnHL8Go3yAv1QmQCPLe5SYaDS/VgM+7ElEKECL
qnM8jehFv/c+0wT0XSpApc3PDWgMSr+2MbvBo1MsQBKnbfFuy1C/xv92K3Nz
LkDofBEnkNxOvy3zgnOoRDBArd83Wvh8UL8GwnMjmj0xQGsMhHIP9ka/iH7O
qZtLMkAlTI3r0olDv5mWUgKgRzNA06kxDzWCI79TnEAxtFg0QGu48uqpRPU+
Ty4Yic9kNUDtzFlw0ShBP9obGbPtXjZAuLVy/Y1lQz8O94OzG243QGY0ljbF
MFA/0S0YhkxrOEDZ2RUrnVlNP9fwlYGEYzlAhY+jOLX6UT+FoX1TzHA6QGSC
+wzvhEo/wq2O9xZsO0BjEJZjAy1LP6inCXJxfDxAtlVFOwO2Nz/QLW4V04c9
QN6nVQLFTDA/iA/8ijeBPkCy1ACoRg4xv+je89arjz9AwyUnD4yzOL/shIp6
EUZAQC+TAbvmA0u/heAPntDBQED2QS/OckJKv/IyyqwXSEFAmLHY3+QCUr8n
M5kkYMVBQEEbycVkWU2/MCqdhzBNQkCntX8K3Q5QvwHPtVMCzEJARAkzXaqM
Q7/zOUO0V0hDQIaY/HoQpkG/uZsFADXPQ0D4yo0xKFb8vker3LQTTURAJLlO
okrDGD+psehUetVEQPlIJy8UaEM/LH5piWRbRUCEkOhPX1lGP3f4/iZQ2EVA
U/x7+m6HUD+Wacmvw19GQOrhznYyqE4/fYiooTjeRkCz7kDEN1JRP4Vt/Ccx
WkdAx2gBrRbVST9hSYWZseBHQFyLUntrvEc/BdMidDNeSEAsfNrjTsE0P31T
9Tk95khA5q3UOfMdID8WmjyUymtJQB1jb5pYbDS/d46YV1noSUC8xz8xmhJA
v6x5KQZwb0pAJtWJJCxBS7+pEs8diO1KQCcRzhmRjU2/eqKpICh2S0AtuSCh
du5Qv234+LdL/EtAqfsZan1JT78n/Fy4cHlMQOQeLuy9mUu/tfb1ox0BTUCI
rZnSuHxDvwufo/jLf01AUVZ/WCx9NL9KHnj3//9NQPPZPyNAg6C+crauGA==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 60.}, {-0.0010993228055538925`, 
                    0.0010973710764625455`}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "60.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA9xwHa8MPsT4AAAAAtQLZO4Q91Tyl
TO8/YzcYecWRMz+t8DvJ0E4AQLu8/t6XYEM/dW6N1I46CEBOevRU3T9LP1BO
KyeG/g9AwNVjGpF7Tz+3TYwWfjUUQFqTqwuY0VA/g2IoYsQjGEAiAuYnBQBP
P/EtbAdKZhxAZcO9zqItSz80FSsodkogQGDlC/7Ov0A/j8ry8Mw9IkBsEiwr
xII0PztbjmZDWyRAee6/GyfnHL8Go3yAv1QmQCPLe5SYaDS/VgM+7ElEKECL
qnM8jehFv/c+0wT0XSpApc3PDWgMSr+2MbvBo1MsQBKnbfFuy1C/xv92K3Nz
LkDofBEnkNxOvy3zgnOoRDBArd83Wvh8UL8GwnMjmj0xQGsMhHIP9ka/iH7O
qZtLMkAlTI3r0olDv5mWUgKgRzNA06kxDzWCI79TnEAxtFg0QGu48uqpRPU+
Ty4Yic9kNUDtzFlw0ShBP9obGbPtXjZAuLVy/Y1lQz8O94OzG243QGY0ljbF
MFA/0S0YhkxrOEDZ2RUrnVlNP9fwlYGEYzlAhY+jOLX6UT+FoX1TzHA6QGSC
+wzvhEo/wq2O9xZsO0BjEJZjAy1LP6inCXJxfDxAtlVFOwO2Nz/QLW4V04c9
QN6nVQLFTDA/iA/8ijeBPkCy1ACoRg4xv+je89arjz9AwyUnD4yzOL/shIp6
EUZAQC+TAbvmA0u/heAPntDBQED2QS/OckJKv/IyyqwXSEFAmLHY3+QCUr8n
M5kkYMVBQEEbycVkWU2/MCqdhzBNQkCntX8K3Q5QvwHPtVMCzEJARAkzXaqM
Q7/zOUO0V0hDQIaY/HoQpkG/uZsFADXPQ0D4yo0xKFb8vker3LQTTURAJLlO
okrDGD+psehUetVEQPlIJy8UaEM/LH5piWRbRUCEkOhPX1lGP3f4/iZQ2EVA
U/x7+m6HUD+Wacmvw19GQOrhznYyqE4/fYiooTjeRkCz7kDEN1JRP4Vt/Ccx
WkdAx2gBrRbVST9hSYWZseBHQFyLUntrvEc/BdMidDNeSEAsfNrjTsE0P31T
9Tk95khA5q3UOfMdID8WmjyUymtJQB1jb5pYbDS/d46YV1noSUC8xz8xmhJA
v6x5KQZwb0pAJtWJJCxBS7+pEs8diO1KQCcRzhmRjU2/eqKpICh2S0AtuSCh
du5Qv234+LdL/EtAqfsZan1JT78n/Fy4cHlMQOQeLuy9mUu/tfb1ox0BTUCI
rZnSuHxDvwufo/jLf01AUVZ/WCx9NL9KHnj3//9NQPPZPyNAg6C+crauGA==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 60.}, {-0.0010993228055538925`, 
                    0.0010973710764625455`}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "60.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->("InterpolatingFunction[{{0., 60.}}, <>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.660833005811377*^9, 3.660835018027557*^9, 3.660835201534309*^9, 
   3.661192656677003*^9, 3.661192751653811*^9, 3.6611929553954906`*^9, {
   3.661193173089547*^9, 3.661193241899117*^9}, {3.661194310041231*^9, 
   3.661194327334326*^9}, 3.661195374982168*^9, 3.662200533767147*^9, 
   3.694200334165691*^9, 3.694200825281021*^9, {3.6942008975100517`*^9, 
   3.694200919349629*^9}, 3.6942009645276957`*^9, 3.6942009971955023`*^9, 
   3.694201224352549*^9}]
}, Open  ]],

Cell["\<\
Plot the solution (phi[t], which doesn\[CloseCurlyQuote]t change much for low \
frequency drives)\
\>", "Text",
 CellChangeTimes->{{3.660833012250332*^9, 3.660833016253186*^9}, {
  3.660833109260655*^9, 3.660833112850033*^9}, {3.694201023678211*^9, 
  3.6942010570383253`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"plotpars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Full"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"1", "/", "4"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"phi", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"Evaluate", "[", "plotpars", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.660833035223577*^9, 3.660833073597073*^9}, {
  3.6608352042179747`*^9, 3.660835205392108*^9}, {3.6611925280041103`*^9, 
  3.661192541677369*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUW2k8FF4XtmSJyL7v+76OMba5hyHMGGYopb8oJEsiW4gSJUkiKiRRtqSy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     "]]}},
  AspectRatio->NCache[
    Rational[1, 4], 0.25],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Full,
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 60}, {-0.0010996371349618324`, 0.0010997854003274255`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.660833076956625*^9, 3.66083501808286*^9, 3.6608352058026543`*^9, 
   3.66119265707733*^9, 3.661192759573637*^9, 3.661192955474865*^9, {
   3.661193173164143*^9, 3.661193241981011*^9}, {3.661194312855249*^9, 
   3.6611943274367228`*^9}, 3.661195375083688*^9, 3.662200533861059*^9, 
   3.694200334284317*^9, 3.6942008286998577`*^9, {3.694200900114197*^9, 
   3.694200923262843*^9}, 3.6942009646267433`*^9, 3.694200997290097*^9, 
   3.694201224448457*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solve the Equations of Motion:
Near resonance drive - beats\
\>", "Subsection",
 CellChangeTimes->{{3.661192395534131*^9, 3.661192407388399*^9}, {
  3.6611928211387577`*^9, 3.661192865383193*^9}, {3.661193284125386*^9, 
  3.661193284939232*^9}, {3.661193414953587*^9, 3.661193416607503*^9}}],

Cell[TextData[{
 "Try different values of ",
 StyleBox["fd", "Input"],
 " near 1..."
}], "Text",
 CellChangeTimes->{{3.661195014344286*^9, 3.661195031985299*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"g", "\[Rule]", "10"}], ",", 
     RowBox[{"l", "\[Rule]", "1"}], ",", 
     RowBox[{"ad", "\[Rule]", "0.01"}], ",", 
     RowBox[{"fd", "\[Rule]", "0.9"}], ",", 
     RowBox[{"phi0", "\[Rule]", "0"}], ",", 
     RowBox[{"v0", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{
    RowBox[{"30", " ", "2", 
     RowBox[{"\[Pi]", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"g", "/", "l"}], "]"}]}]}], "/.", "pars"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eom", ",", "incon"}], "}"}], "//.", "pars"}], ",", "dvars", 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
    RowBox[{"MaxStepSize", "\[Rule]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"10", " ", "fd"}], ")"}]}], "/.", "pars"}], "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"phi", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"Evaluate", "[", "plotpars", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.660832934883301*^9, 3.6608329811674843`*^9}, {
  3.66083518203434*^9, 3.660835186864388*^9}, {3.6611924588876343`*^9, 
  3.6611924687916613`*^9}, {3.661192715248855*^9, 3.6611927435998173`*^9}, {
  3.661192902039855*^9, 3.6611929408869123`*^9}, {3.661193088336308*^9, 
  3.661193090829599*^9}, {3.661193152562392*^9, 3.661193214374984*^9}, {
  3.661193313245545*^9, 3.661193378312942*^9}, {3.6611934719106817`*^9, 
  3.6611935030993423`*^9}, {3.661194287683972*^9, 3.661194294124902*^9}, {
  3.661194964933239*^9, 3.661194985497007*^9}, {3.662203545541556*^9, 
  3.6622035593372087`*^9}, {3.66220853201229*^9, 3.662208576626711*^9}, {
  3.694201309093463*^9, 3.694201321835462*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"phi", "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["InterpolatingFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAfgkCbDHzsD4AAADlCl88PBSyN707
GO8/fJZn5Seqij/0W4XjgTMAQG/4YU0faZq/0ix/ZfwRCEAkhT6mg1OiP2lD
JsryyA9Alw5w3265pL8lNKjdphMUQC60Aetiyqg/TXceHVj7F0DUg0IoE3Sn
v5pB1qK7NhxAdwp/KzWRqj9iV/KMLi8gQADtrqJ4cKu/UybqK0EfIkDAcMPM
336kP9a4Au4sOSRAGs2NlmDhpL+144uTWi8mQGKno2pK8Zk/AmDAMacbKEDF
lpOq7RNzv+KfFfPMMSpA7CXhNQi6aD8deNuXNCQsQKe8N9k2n4g/6xPCX3VA
LkByad9JP9uDv5QAKpBqKTBADF2kbH/xhD9gQytiuyAxQC+p0thQEJG/9ue8
xfgsMkCHEvUR652IP7rYBhtXJzNA/HjH9Os/gr9HK+EBojY0QJ04G3SYYVs/
iyYRZfxANUBXGHgxuYp2P/1t+bl3OTZAr2ZGIH8Pkr84F3Kg30Y3QEq1fajr
bJo/oQyjeGhCOEDD1r+Z4IGkv8GqKc0AOTlAIJDP+9xIrD+qqkCzhUQ6QAE9
Y09AJbC/wfYPiys+O0BVjIZX5LiyP6Kkb/S9TDxAwj+PrIK9s786+yTaX1Y9
QFrFFaRgarQ/AJ6SsSJOPkDCler3Dqe0v4+ikBrSWj9AZuQsvagktD+meaM6
0SpAQImhUdUTc7K/X3YpJsGlQEAB5/R84lquP/2jd1onK0FAb2PDIwqTqr+y
96EHnqdBQCeabvwHt6I/THyU/YouQkBsSrQg1Mudv/0mY2yIrEJAurQzMXk4
kD8JplyZDShDQFq4wFGkUnC/+lUeDwmuQ0BWhdvH23VXvwIsvP0UK0RArGvA
sB+Udj/uMiI1l7JEQAWOTX9QQ4K/Ng6zKqE3RUDSrv8a//6GP5UPIJm7s0VA
WujB6d9Dbr/YQVVQTDpGQI8sgjg6G3E/MppmgO23RkB+C3GVWu2AP+jGom4W
M0dAPVkHkreLm7+DJKeltbhHQLF5oF3/CJ8/NaiHVWU1SEA8D8naHyCov8tc
ME6LvEhA1jJacXj5pz+95QMFOUFJQBJE8sFOFKm/xpSzNPe8SUBkknDS4mGv
P7N0K60rQ0pAQO1VAOObrb+3en+ecMBKQLM3PfESGK8/oLGb2CtIS0BU4f0Z
3deqv+S84tBuzUtABGFkicHHpj8/7gVCwklMQLSX3Vten6O/f1Dx+4vQTECu
AQe+YS6bP9bYuC5mTk1AQn1rp993jr/A3CR/w81NQCOimkFgwls/s428FA==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    59.60752959477661}, {-0.08067410996098714, 
                    0.07974819189054952}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "59.60752959477661`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAfgkCbDHzsD4AAADlCl88PBSyN707
GO8/fJZn5Seqij/0W4XjgTMAQG/4YU0faZq/0ix/ZfwRCEAkhT6mg1OiP2lD
JsryyA9Alw5w3265pL8lNKjdphMUQC60Aetiyqg/TXceHVj7F0DUg0IoE3Sn
v5pB1qK7NhxAdwp/KzWRqj9iV/KMLi8gQADtrqJ4cKu/UybqK0EfIkDAcMPM
336kP9a4Au4sOSRAGs2NlmDhpL+144uTWi8mQGKno2pK8Zk/AmDAMacbKEDF
lpOq7RNzv+KfFfPMMSpA7CXhNQi6aD8deNuXNCQsQKe8N9k2n4g/6xPCX3VA
LkByad9JP9uDv5QAKpBqKTBADF2kbH/xhD9gQytiuyAxQC+p0thQEJG/9ue8
xfgsMkCHEvUR652IP7rYBhtXJzNA/HjH9Os/gr9HK+EBojY0QJ04G3SYYVs/
iyYRZfxANUBXGHgxuYp2P/1t+bl3OTZAr2ZGIH8Pkr84F3Kg30Y3QEq1fajr
bJo/oQyjeGhCOEDD1r+Z4IGkv8GqKc0AOTlAIJDP+9xIrD+qqkCzhUQ6QAE9
Y09AJbC/wfYPiys+O0BVjIZX5LiyP6Kkb/S9TDxAwj+PrIK9s786+yTaX1Y9
QFrFFaRgarQ/AJ6SsSJOPkDCler3Dqe0v4+ikBrSWj9AZuQsvagktD+meaM6
0SpAQImhUdUTc7K/X3YpJsGlQEAB5/R84lquP/2jd1onK0FAb2PDIwqTqr+y
96EHnqdBQCeabvwHt6I/THyU/YouQkBsSrQg1Mudv/0mY2yIrEJAurQzMXk4
kD8JplyZDShDQFq4wFGkUnC/+lUeDwmuQ0BWhdvH23VXvwIsvP0UK0RArGvA
sB+Udj/uMiI1l7JEQAWOTX9QQ4K/Ng6zKqE3RUDSrv8a//6GP5UPIJm7s0VA
WujB6d9Dbr/YQVVQTDpGQI8sgjg6G3E/MppmgO23RkB+C3GVWu2AP+jGom4W
M0dAPVkHkreLm7+DJKeltbhHQLF5oF3/CJ8/NaiHVWU1SEA8D8naHyCov8tc
ME6LvEhA1jJacXj5pz+95QMFOUFJQBJE8sFOFKm/xpSzNPe8SUBkknDS4mGv
P7N0K60rQ0pAQO1VAOObrb+3en+ecMBKQLM3PfESGK8/oLGb2CtIS0BU4f0Z
3deqv+S84tBuzUtABGFkicHHpj8/7gVCwklMQLSX3Vten6O/f1Dx+4vQTECu
AQe+YS6bP9bYuC5mTk1AQn1rp993jr/A3CR/w81NQCOimkFgwls/s428FA==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    59.60752959477661}, {-0.08067410996098714, 
                    0.07974819189054952}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "59.60752959477661`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->(
       "InterpolatingFunction[{{0., 59.6075}}, <>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193472609458*^9, 3.6611935038266897`*^9}, {3.661194289059945*^9, 
   3.66119429468342*^9}, 3.661194327506916*^9, {3.661194965761526*^9, 
   3.661194985887827*^9}, 3.661195375162526*^9, 3.662200533965374*^9, {
   3.662203547413974*^9, 3.662203560073228*^9}, {3.662208535772209*^9, 
   3.6622085772563467`*^9}, 3.6942003343645773`*^9, 3.6942012336854897`*^9, {
   3.694201313326255*^9, 3.694201322443695*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUV3c41u8Xtsree++9X7PIc6KQvklWQoWQ7FVEIdl7Ze/XeO1ZRniUVEaS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     "]]}},
  AspectRatio->NCache[
    Rational[1, 4], 0.25],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Full,
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->
   NCache[{{0, 6 10^Rational[1, 2] Pi}, {-0.08092691530385376, 
     0.08081566853394244}}, {{0, 59.60752959477661}, {-0.08092691530385376, 
     0.08081566853394244}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193472609458*^9, 3.6611935038266897`*^9}, {3.661194289059945*^9, 
   3.66119429468342*^9}, 3.661194327506916*^9, {3.661194965761526*^9, 
   3.661194985887827*^9}, 3.661195375162526*^9, 3.662200533965374*^9, {
   3.662203547413974*^9, 3.662203560073228*^9}, {3.662208535772209*^9, 
   3.6622085772563467`*^9}, 3.6942003343645773`*^9, 3.6942012336854897`*^9, {
   3.694201313326255*^9, 3.694201322531022*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solve the Equations of Motion:
On resonance drive - saturation\
\>", "Subsection",
 CellChangeTimes->{{3.661192395534131*^9, 3.661192407388399*^9}, {
  3.6611928211387577`*^9, 3.661192865383193*^9}, {3.661193284125386*^9, 
  3.661193284939232*^9}, {3.661193414953587*^9, 3.66119343431916*^9}}],

Cell[TextData[{
 "Try different values of ",
 StyleBox["ad", "Input"],
 " and note how the saturation time and amplitude change"
}], "Text",
 CellChangeTimes->{{3.661195014344286*^9, 3.661195070752245*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"g", "\[Rule]", "10"}], ",", 
     RowBox[{"l", "\[Rule]", "1"}], ",", 
     RowBox[{"ad", "\[Rule]", "0.02"}], ",", 
     RowBox[{"fd", "\[Rule]", "1"}], ",", 
     RowBox[{"phi0", "\[Rule]", "0"}], ",", 
     RowBox[{"v0", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{
    RowBox[{"30", " ", "2", 
     RowBox[{"\[Pi]", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"g", "/", "l"}], "]"}]}]}], "/.", "pars"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eom", ",", "incon"}], "}"}], "//.", "pars"}], ",", "dvars", 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
    RowBox[{"MaxStepSize", "\[Rule]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"10", " ", "fd"}], ")"}]}], "/.", "pars"}], "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"phi", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"Evaluate", "[", "plotpars", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.660832934883301*^9, 3.6608329811674843`*^9}, {
  3.66083518203434*^9, 3.660835186864388*^9}, {3.6611924588876343`*^9, 
  3.6611924687916613`*^9}, {3.661192715248855*^9, 3.6611927435998173`*^9}, {
  3.661192902039855*^9, 3.6611929408869123`*^9}, {3.661193088336308*^9, 
  3.661193090829599*^9}, {3.661193152562392*^9, 3.661193214374984*^9}, {
  3.661193313245545*^9, 3.661193378312942*^9}, {3.661193438504074*^9, 
  3.661193458723958*^9}, {3.661193521301283*^9, 3.661193521351925*^9}, {
  3.6611942608727493`*^9, 3.661194276613223*^9}, {3.661195114831707*^9, 
  3.6611951243906918`*^9}, {3.66220864895617*^9, 3.6622086744119062`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"phi", "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["InterpolatingFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAfgkCbDHzsD4AACA9O2ZTPBSyN707
GO8/Iayo3vkLoD/0W4XjgTMAQAhnfKe+7q+/0ix/ZfwRCEAf8h1HQQi4P2lD
JsryyA9A2NcUf9UVwL8lNKjdphMUQI4riGwY28M/TXceHVj7F0CMoWa3+ALI
v5pB1qK7NhxAWVT7GVvqyj9iV/KMLi8gQPAX8DPDNc2/UybqK0EfIkBDCoxG
LAvRP9a4Au4sOSRA2LQWzVOL0b+144uTWi8mQAjDZebd4tM/AmDAMacbKECO
0QXmus/Wv+KfFfPMMSpApZllRF1b1z8deNuXNCQsQO6BJdcpMNq/6xPCX3VA
LkBJHrZ/aObZP5QAKpBqKTBAkeSHcKHl2b9gQytiuyAxQAcS6xef1N0/9ue8
xfgsMkCM8F45TSfdv7rYBhtXJzNAY0zixrtl4D9HK+EBojY0QGpmtsHyEd+/
iyYRZfxANUCWkx6tmT7eP/1t+bl3OTZAzxW3Kpy24b84F3Kg30Y3QL8Heznb
5+A/oQyjeGhCOEBtR+Kqcy7jv8GqKc0AOTlAXWkUnMD05T+qqkCzhUQ6QBvX
6R132eW/wfYPiys+O0Bk8d7cfPvnP6Kkb/S9TDxAhTErQqiR5786+yTaX1Y9
QBbdTmPhoOc/AJ6SsSJOPkCDKe08ssDpv4+ikBrSWj9AuNm3/R956T+meaM6
0SpAQIoOgN5BrOq/X3YpJsGlQEAYNAptNivrP/2jd1onK0FA94qD2WYL67+y
96EHnqdBQEq5DDu7gOo/THyU/YouQkDUv3xtHWPqv/0mY2yIrEJAB6ylcvh1
6T8JplyZDShDQMAorgZDiee/+lUeDwmuQ0AR4F4b8ojnPwIsvP0UK0RA4lJ8
BXWP5b/uMiI1l7JEQMsOxPg78OU/Ng6zKqE3RUAXc8J1opvlv5UPIJm7s0VA
canOgySm4z/YQVVQTDpGQJU5Pm5aseO/MppmgO23RkBmm3Qx2BfiP+jGom4W
M0dAjnnLLaOm37+DJKeltbhHQOy9DqQP898/NaiHVWU1SEDP5zCxqmLcv8tc
ME6LvEhAz4EONRYe3T+95QMFOUFJQE4pxS4yZ9y/xpSzNPe8SUBdYFzB8EvZ
P7N0K60rQ0pAYPyTm/Xb2L+3en+ecMBKQI/VLUE2ZNY/oLGb2CtIS0CKgCvC
gKXVv+S84tBuzUtAAP/nOsP10z8/7gVCwklMQJ7oFVz/0tG/f1Dx+4vQTEBJ
nqbFIN7PP9bYuC5mTk1Akk5IqEniy7/A3CR/w81NQNPNQsBt3Mc/IdvN4A==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    59.60752959477661}, {-0.8451418159787342, 
                    0.8490249757466044}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "59.60752959477661`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAfgkCbDHzsD4AACA9O2ZTPBSyN707
GO8/Iayo3vkLoD/0W4XjgTMAQAhnfKe+7q+/0ix/ZfwRCEAf8h1HQQi4P2lD
JsryyA9A2NcUf9UVwL8lNKjdphMUQI4riGwY28M/TXceHVj7F0CMoWa3+ALI
v5pB1qK7NhxAWVT7GVvqyj9iV/KMLi8gQPAX8DPDNc2/UybqK0EfIkBDCoxG
LAvRP9a4Au4sOSRA2LQWzVOL0b+144uTWi8mQAjDZebd4tM/AmDAMacbKECO
0QXmus/Wv+KfFfPMMSpApZllRF1b1z8deNuXNCQsQO6BJdcpMNq/6xPCX3VA
LkBJHrZ/aObZP5QAKpBqKTBAkeSHcKHl2b9gQytiuyAxQAcS6xef1N0/9ue8
xfgsMkCM8F45TSfdv7rYBhtXJzNAY0zixrtl4D9HK+EBojY0QGpmtsHyEd+/
iyYRZfxANUCWkx6tmT7eP/1t+bl3OTZAzxW3Kpy24b84F3Kg30Y3QL8Heznb
5+A/oQyjeGhCOEBtR+Kqcy7jv8GqKc0AOTlAXWkUnMD05T+qqkCzhUQ6QBvX
6R132eW/wfYPiys+O0Bk8d7cfPvnP6Kkb/S9TDxAhTErQqiR5786+yTaX1Y9
QBbdTmPhoOc/AJ6SsSJOPkCDKe08ssDpv4+ikBrSWj9AuNm3/R956T+meaM6
0SpAQIoOgN5BrOq/X3YpJsGlQEAYNAptNivrP/2jd1onK0FA94qD2WYL67+y
96EHnqdBQEq5DDu7gOo/THyU/YouQkDUv3xtHWPqv/0mY2yIrEJAB6ylcvh1
6T8JplyZDShDQMAorgZDiee/+lUeDwmuQ0AR4F4b8ojnPwIsvP0UK0RA4lJ8
BXWP5b/uMiI1l7JEQMsOxPg78OU/Ng6zKqE3RUAXc8J1opvlv5UPIJm7s0VA
canOgySm4z/YQVVQTDpGQJU5Pm5aseO/MppmgO23RkBmm3Qx2BfiP+jGom4W
M0dAjnnLLaOm37+DJKeltbhHQOy9DqQP898/NaiHVWU1SEDP5zCxqmLcv8tc
ME6LvEhAz4EONRYe3T+95QMFOUFJQE4pxS4yZ9y/xpSzNPe8SUBdYFzB8EvZ
P7N0K60rQ0pAYPyTm/Xb2L+3en+ecMBKQI/VLUE2ZNY/oLGb2CtIS0CKgCvC
gKXVv+S84tBuzUtAAP/nOsP10z8/7gVCwklMQJ7oFVz/0tG/f1Dx+4vQTEBJ
nqbFIN7PP9bYuC5mTk1Akk5IqEniy7/A3CR/w81NQNPNQsBt3Mc/IdvN4A==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    59.60752959477661}, {-0.8451418159787342, 
                    0.8490249757466044}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "59.60752959477661`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->(
       "InterpolatingFunction[{{0., 59.6075}}, <>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, {
   3.6611942668675413`*^9, 3.661194277172256*^9}, 3.66119432766707*^9, {
   3.661195115687459*^9, 3.661195125006225*^9}, 3.661195375336061*^9, 
   3.662200534146503*^9, {3.662208650022625*^9, 3.662208675212379*^9}, 
   3.694200334532443*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUWHc8198XlmTvvcre+2OWck9RREmKpJKVr+wkLSGpiGQlZBVCWdmzS/be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     "]]}},
  AspectRatio->NCache[
    Rational[1, 4], 0.25],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Full,
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->
   NCache[{{0, 6 10^Rational[1, 2] Pi}, {-0.8492655506168592, 
     0.8491394802049287}}, {{0, 59.60752959477661}, {-0.8492655506168592, 
     0.8491394802049287}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, {
   3.6611942668675413`*^9, 3.661194277172256*^9}, 3.66119432766707*^9, {
   3.661195115687459*^9, 3.661195125006225*^9}, 3.661195375336061*^9, 
   3.662200534146503*^9, {3.662208650022625*^9, 3.662208675212379*^9}, 
   3.694200334619465*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solve the Equations of Motion:
No dirve, big swing - anharmonic\
\>", "Subsection",
 CellChangeTimes->{{3.661192395534131*^9, 3.661192407388399*^9}, {
  3.6611928211387577`*^9, 3.661192865383193*^9}, {3.661193284125386*^9, 
  3.661193284939232*^9}, {3.661193414953587*^9, 3.66119343431916*^9}, {
  3.6611935887812777`*^9, 3.6611936074181547`*^9}, {3.661194911278949*^9, 
  3.6611949154525537`*^9}}],

Cell[TextData[{
 "Try different values of ",
 StyleBox["phi0", "Input"],
 " and note how the number of cycles changes (it should be 5 for low \
amplitude)."
}], "Text",
 CellChangeTimes->{{3.661195014344286*^9, 3.661195070752245*^9}, {
  3.661195142223633*^9, 3.661195180564883*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"g", "\[Rule]", "10"}], ",", 
     RowBox[{"l", "\[Rule]", "1"}], ",", 
     RowBox[{"ad", "\[Rule]", "0.0"}], ",", 
     RowBox[{"fd", "\[Rule]", "0.1"}], ",", 
     RowBox[{"phi0", "\[Rule]", "2"}], " ", ",", 
     RowBox[{"v0", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{
    RowBox[{"5", " ", "2", 
     RowBox[{"\[Pi]", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"g", "/", "l"}], "]"}]}]}], "/.", "pars"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eom", ",", "incon"}], "}"}], "//.", "pars"}], ",", "dvars", 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
    RowBox[{"MaxStepSize", "\[Rule]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"10", " ", "fd"}], ")"}]}], "/.", "pars"}], "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"phi", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"Evaluate", "[", "plotpars", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.660832934883301*^9, 3.6608329811674843`*^9}, {
  3.66083518203434*^9, 3.660835186864388*^9}, {3.6611924588876343`*^9, 
  3.6611924687916613`*^9}, {3.661192715248855*^9, 3.6611927435998173`*^9}, {
  3.661192902039855*^9, 3.6611929408869123`*^9}, {3.661193088336308*^9, 
  3.661193090829599*^9}, {3.661193152562392*^9, 3.661193214374984*^9}, {
  3.661193313245545*^9, 3.661193378312942*^9}, {3.661193438504074*^9, 
  3.661193458723958*^9}, {3.661193521301283*^9, 3.661193521351925*^9}, {
  3.661193613244508*^9, 3.661193624555544*^9}, {3.661194226937459*^9, 
  3.6611942378027067`*^9}, {3.661194342886291*^9, 3.66119439561628*^9}, {
  3.66119447694575*^9, 3.6611945109544363`*^9}, {3.66119458211207*^9, 
  3.6611945894630413`*^9}, {3.6622087543858967`*^9, 3.662208799712842*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"phi", "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["InterpolatingFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA/mGtOpeZhj5//f//////P2MhJX7S
usQ/urFeIFgT/j/wz7GEAprVP4ckfATcdfc/N3P/mP0L4D+L0vBva+/pP0aC
GdyhMOU/MLdl4Gethr+HReB83sTqP3sLlG/Bkuy/Z/R90cr57z93f01CDUv4
v7wr5MEnz/I/Fo/DB7V3/r8tH0MRPpT1PzN6B+Hj8P+/boiNOqwp+D9Zgt+U
Klj9v8hLrpLm9vo/xfTfZX/69b/yhLrEeJT9P/4ytzzZx+W/AUCAdm8SAEB3
7hzvUIPDP5ZqDqKIdgFAMRLT4x8n8D8TUJK6zcICQHi+5NZjf/k/nGKB6vgq
BEAf6H3CDPX+PxlWjRWOjAVAqvM0iTrL/z9+BI8tT9YGQPeKUZkDnfw/79/7
XPY7CECU5V/NT5r0P0h2XnnJiQlAiuoFRkUV4j+uOSytgvMKQLxNZb+hG9e/
CN4W3KVWDEDyQaWnNMfyv0o99/f0oQ1At+z6i98d+7+YyUIrKgkPQAZuJXkO
hf+/ZwjCpUUsEEBXdOpApoD/v3wccTOr0BBAeEEQrhaf+78Yx9XMA4MRQANm
g5nl1/K/KE+1XHIpEkDS2n15gwzbv75tSvjT3RJA4wvpZXoV4D/O/G2R6o4T
QCICuCIkdfQ/UmkMIRc0FECUnyLH1xb8P1xsYLw25xRAHWUkDYDH/z/aTC9O
bI4VQBms/In2JP8/0p2M3VYyFkCTXjZ5lqb6P1CFn3g05BZAqKwtoAk48T9C
Si0KKIoXQMDVzPmA/NI/uqVwpw4+GEDFRVHOOufjv6beLjsL5hhARSGmVGpV
9b8MiHvMvIoZQBnLv0/hkfy/+Md9aWE9GkD/b3Zwf+D/v1jl+vwb5BpACuR5
Ecrq/r8+mS2cyZgbQFl/sVOQXvm/n73uOCxKHEA4BBIZTFruv3O/Ksyk7xxA
kyvh/bt2wr/OVxxrEKMdQBimihE+Veg/nc2IAJJKHkDDNqQsFOP2P+azg5PI
7h5A0RNBQa9l/T+1MDQy8qAfQNcsZHNM/P8/e8Wv45gjIEAnPsxUsmP+P989
IDSyfSBAD+jpe/Uh+D+A7lcDJtYgQLTzLpU1m+o/2w3NzaQoIUBQHEKBp7yF
P3r4HB4dgiFAMG4sxtUI7L/TUappoNUhQHbA6PTIIfi/b3YSOx0wIkANL8JS
3Gf+v0jTQYv0iCJA1Wlpa2bz/7/bnq7W1tsiQIWJ0bsQZ/2/sTX2p7I1I0D0
sbPbYRL2v0E7e3SZiSNAwIlrAqH65b/VPcNUgt4jQC5sEh5XcMY/3dzhUA==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    9.934588265796101}, {-1.9969238467953023`, 
                    1.9999999999998577`}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "9.934588265796101`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA/mGtOpeZhj5//f//////P2MhJX7S
usQ/urFeIFgT/j/wz7GEAprVP4ckfATcdfc/N3P/mP0L4D+L0vBva+/pP0aC
GdyhMOU/MLdl4Gethr+HReB83sTqP3sLlG/Bkuy/Z/R90cr57z93f01CDUv4
v7wr5MEnz/I/Fo/DB7V3/r8tH0MRPpT1PzN6B+Hj8P+/boiNOqwp+D9Zgt+U
Klj9v8hLrpLm9vo/xfTfZX/69b/yhLrEeJT9P/4ytzzZx+W/AUCAdm8SAEB3
7hzvUIPDP5ZqDqKIdgFAMRLT4x8n8D8TUJK6zcICQHi+5NZjf/k/nGKB6vgq
BEAf6H3CDPX+PxlWjRWOjAVAqvM0iTrL/z9+BI8tT9YGQPeKUZkDnfw/79/7
XPY7CECU5V/NT5r0P0h2XnnJiQlAiuoFRkUV4j+uOSytgvMKQLxNZb+hG9e/
CN4W3KVWDEDyQaWnNMfyv0o99/f0oQ1At+z6i98d+7+YyUIrKgkPQAZuJXkO
hf+/ZwjCpUUsEEBXdOpApoD/v3wccTOr0BBAeEEQrhaf+78Yx9XMA4MRQANm
g5nl1/K/KE+1XHIpEkDS2n15gwzbv75tSvjT3RJA4wvpZXoV4D/O/G2R6o4T
QCICuCIkdfQ/UmkMIRc0FECUnyLH1xb8P1xsYLw25xRAHWUkDYDH/z/aTC9O
bI4VQBms/In2JP8/0p2M3VYyFkCTXjZ5lqb6P1CFn3g05BZAqKwtoAk48T9C
Si0KKIoXQMDVzPmA/NI/uqVwpw4+GEDFRVHOOufjv6beLjsL5hhARSGmVGpV
9b8MiHvMvIoZQBnLv0/hkfy/+Md9aWE9GkD/b3Zwf+D/v1jl+vwb5BpACuR5
Ecrq/r8+mS2cyZgbQFl/sVOQXvm/n73uOCxKHEA4BBIZTFruv3O/Ksyk7xxA
kyvh/bt2wr/OVxxrEKMdQBimihE+Veg/nc2IAJJKHkDDNqQsFOP2P+azg5PI
7h5A0RNBQa9l/T+1MDQy8qAfQNcsZHNM/P8/e8Wv45gjIEAnPsxUsmP+P989
IDSyfSBAD+jpe/Uh+D+A7lcDJtYgQLTzLpU1m+o/2w3NzaQoIUBQHEKBp7yF
P3r4HB4dgiFAMG4sxtUI7L/TUappoNUhQHbA6PTIIfi/b3YSOx0wIkANL8JS
3Gf+v0jTQYv0iCJA1Wlpa2bz/7/bnq7W1tsiQIWJ0bsQZ/2/sTX2p7I1I0D0
sbPbYRL2v0E7e3SZiSNAwIlrAqH65b/VPcNUgt4jQC5sEh5XcMY/3dzhUA==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    9.934588265796101}, {-1.9969238467953023`, 
                    1.9999999999998577`}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "9.934588265796101`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->(
       "InterpolatingFunction[{{0., 9.93459}}, <>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, 
   3.661193627062294*^9, {3.661194232773589*^9, 3.661194238450338*^9}, {
   3.661194327833428*^9, 3.661194396382039*^9}, 3.6611945146420717`*^9, 
   3.661194590009468*^9, 3.661195375561357*^9, 3.662200534327178*^9, {
   3.662208766983037*^9, 3.662208800402245*^9}, 3.69420033470582*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUWnk8VN8btpN17Ix9krIkUUhyXqVIQguJFmXNUomUKL5CKqlUshWiLCXJ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     "]]}},
  AspectRatio->NCache[
    Rational[1, 4], 0.25],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Full,
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->
   NCache[{{0, 10^Rational[1, 2] Pi}, {-1.9999987103446677`, 
     1.9999999999997897`}}, {{0, 9.934588265796101}, {-1.9999987103446677`, 
     1.9999999999997897`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, 
   3.661193627062294*^9, {3.661194232773589*^9, 3.661194238450338*^9}, {
   3.661194327833428*^9, 3.661194396382039*^9}, 3.6611945146420717`*^9, 
   3.661194590009468*^9, 3.661195375561357*^9, 3.662200534327178*^9, {
   3.662208766983037*^9, 3.662208800402245*^9}, 3.694200334772311*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solve the Equations of Motion:
High Frequency Drive - strange\
\>", "Subsection",
 CellChangeTimes->{{3.661192395534131*^9, 3.661192407388399*^9}, {
  3.6611928211387577`*^9, 3.661192865383193*^9}, {3.661193284125386*^9, 
  3.661193284939232*^9}, {3.661193414953587*^9, 3.66119343431916*^9}, {
  3.6611935887812777`*^9, 3.6611936074181547`*^9}, {3.661193648939554*^9, 
  3.661193674487999*^9}, {3.6611937200810013`*^9, 3.661193723822339*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"g", "\[Rule]", "10"}], ",", 
     RowBox[{"l", "\[Rule]", "1"}], ",", 
     RowBox[{"ad", "\[Rule]", "0.2"}], ",", 
     RowBox[{"fd", "\[Rule]", "10"}], ",", 
     RowBox[{"phi0", "\[Rule]", 
      RowBox[{"\[Pi]", "/", "2"}]}], ",", 
     RowBox[{"v0", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{
    RowBox[{"5", " ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"g", "/", "l"}], "]"}]}], "/.", "pars"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eom", ",", "incon"}], "}"}], "//.", "pars"}], ",", "dvars", 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
    RowBox[{"MaxStepSize", "\[Rule]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"10", " ", "fd"}], ")"}]}], "/.", "pars"}], "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"phi", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"Evaluate", "[", "plotpars", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.660832934883301*^9, 3.6608329811674843`*^9}, {
  3.66083518203434*^9, 3.660835186864388*^9}, {3.6611924588876343`*^9, 
  3.6611924687916613`*^9}, {3.661192715248855*^9, 3.6611927435998173`*^9}, {
  3.661192902039855*^9, 3.6611929408869123`*^9}, {3.661193088336308*^9, 
  3.661193090829599*^9}, {3.661193152562392*^9, 3.661193214374984*^9}, {
  3.661193313245545*^9, 3.661193378312942*^9}, {3.661193438504074*^9, 
  3.661193458723958*^9}, {3.661193521301283*^9, 3.661193521351925*^9}, {
  3.661193613244508*^9, 3.661193624555544*^9}, {3.6611936799724407`*^9, 
  3.661193702626865*^9}, {3.6942013780306177`*^9, 3.694201495540567*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"phi", "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["InterpolatingFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA1try3Qb8kT6kJURU+yH5P9il3vII
f9A/fbUlbxAG8z8+EmxapDDhP+KpQlT7luk/5bzU8xGK6T9zLT4KJnTRPxtI
qgLJ3PA/HMeNnQXtrL9uAyEHV031PwadhK7AM84/bLTN5wty+T+WY0xLofdU
vxU3McSO7/0/3dX+HRD7wb8JJ1BuDSwBQIqaCeMFMbI/Xa2i6GY6A0CRwrnU
OQLYv4ec0GAndQVA+AscN3065L+GhhlH+4kHQI6goNLXUvG/sDpoy1OUCUCJ
u/uZTOH4v69Xkk0TywtAsv3vkHSa9L+Db9c95tsNQGUoUPtVEeO/Fvj7FZAM
EED+7oTL+Sfgv4AdD1zvJRFAMPhQPmnnpr9VwC9ZWCwSQDXhFRAQK7g/lBc+
1fRIE0AQ3sgvCvXJvz7sWQibUhRAJxMA5ipTvz9TdWO6dHIVQKeR5P/W08A/
feNvuxCNFkDczZPIimHBPxLPiXO2lBdAzYsweuqR5z8Rb5Gqj7IYQF/9/bey
0/I/e4ymmHK9GUA4r/5w2hX5P/qOvtUXwxpAe3VBfrkJ9j/kRcSR8N4bQEAb
v5s9o+Q/OHrXBNPnHEDNMo9QR/TJP/di2PboBh5AJmi2yaFA1T/LMNw3wSAf
QF7+mkAXl76/Bb72l9ETIEAzeniwiYalv9k9dlNcoiBAtKNU5t62vz9jfHzq
aychQFBzszGuo9C/dy0EqdypIUAMiYnF+h7Rv8G4AidnNyJAZ68DboKv1L/A
AoiAdrsiQGkiG2J6oPC/9CaEmZ9KI0CIoKWlBWH4v94JB45N0CNATdoSxTk6
979SXwuqXFMkQLUcswZge/C//I6GhYXhJECe5xje9IPXv1t9iDwzZiVAXZjP
HnRxoL/vRQGz+vUlQJub6yAIb9G/DoH7UCODJkAbI4f3JtvBP+J6fMrQBidA
sMOEDBiwsz/sTnQDmJUnQASBw1N3nbu/q+HyF+QaKEDs1BzcPBzTP/Xm8lOR
nShAsDCs4l+W1z90xmlPWCspQJ8KR/XyFOE/qGRnJqSvKUCVjFGp3VX0PxHd
27wJPypAydz711Aj+T8FyNF60MsqQLcdbnUc/PI/rnFOFBxPK0BASdDry6Lp
P431QW2B3StAxGupJqhhwj8hOLyha2IsQCp3mDUEaaI/6lStlW/yLEArAzL3
X5LKPz7kH7HUfy1AxHKXoXRbyb9HMhmovgMuQMYlf1uaCF2/hlqJXsKSLkD3
GXPZJhmjv3pBgPBKGC9AmDfc1j023b+57pJAbp8vQE1EqXDPoOC/nY/UCA==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    15.811388300841898`}, {-1.5550046935056534`, 
                    1.5711220204228076`}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "15.811388300841898`"}], "}"}], "}"}],
                     "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA1try3Qb8kT6kJURU+yH5P9il3vII
f9A/fbUlbxAG8z8+EmxapDDhP+KpQlT7luk/5bzU8xGK6T9zLT4KJnTRPxtI
qgLJ3PA/HMeNnQXtrL9uAyEHV031PwadhK7AM84/bLTN5wty+T+WY0xLofdU
vxU3McSO7/0/3dX+HRD7wb8JJ1BuDSwBQIqaCeMFMbI/Xa2i6GY6A0CRwrnU
OQLYv4ec0GAndQVA+AscN3065L+GhhlH+4kHQI6goNLXUvG/sDpoy1OUCUCJ
u/uZTOH4v69Xkk0TywtAsv3vkHSa9L+Db9c95tsNQGUoUPtVEeO/Fvj7FZAM
EED+7oTL+Sfgv4AdD1zvJRFAMPhQPmnnpr9VwC9ZWCwSQDXhFRAQK7g/lBc+
1fRIE0AQ3sgvCvXJvz7sWQibUhRAJxMA5ipTvz9TdWO6dHIVQKeR5P/W08A/
feNvuxCNFkDczZPIimHBPxLPiXO2lBdAzYsweuqR5z8Rb5Gqj7IYQF/9/bey
0/I/e4ymmHK9GUA4r/5w2hX5P/qOvtUXwxpAe3VBfrkJ9j/kRcSR8N4bQEAb
v5s9o+Q/OHrXBNPnHEDNMo9QR/TJP/di2PboBh5AJmi2yaFA1T/LMNw3wSAf
QF7+mkAXl76/Bb72l9ETIEAzeniwiYalv9k9dlNcoiBAtKNU5t62vz9jfHzq
aychQFBzszGuo9C/dy0EqdypIUAMiYnF+h7Rv8G4AidnNyJAZ68DboKv1L/A
AoiAdrsiQGkiG2J6oPC/9CaEmZ9KI0CIoKWlBWH4v94JB45N0CNATdoSxTk6
979SXwuqXFMkQLUcswZge/C//I6GhYXhJECe5xje9IPXv1t9iDwzZiVAXZjP
HnRxoL/vRQGz+vUlQJub6yAIb9G/DoH7UCODJkAbI4f3JtvBP+J6fMrQBidA
sMOEDBiwsz/sTnQDmJUnQASBw1N3nbu/q+HyF+QaKEDs1BzcPBzTP/Xm8lOR
nShAsDCs4l+W1z90xmlPWCspQJ8KR/XyFOE/qGRnJqSvKUCVjFGp3VX0PxHd
27wJPypAydz711Aj+T8FyNF60MsqQLcdbnUc/PI/rnFOFBxPK0BASdDry6Lp
P431QW2B3StAxGupJqhhwj8hOLyha2IsQCp3mDUEaaI/6lStlW/yLEArAzL3
X5LKPz7kH7HUfy1AxHKXoXRbyb9HMhmovgMuQMYlf1uaCF2/hlqJXsKSLkD3
GXPZJhmjv3pBgPBKGC9AmDfc1j023b+57pJAbp8vQE1EqXDPoOC/nY/UCA==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    15.811388300841898`}, {-1.5550046935056534`, 
                    1.5711220204228076`}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "15.811388300841898`"}], "}"}], "}"}],
                     "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->(
       "InterpolatingFunction[{{0., 15.8114}}, <>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, 
   3.661193627062294*^9, {3.661193685376652*^9, 3.661193703211871*^9}, 
   3.6611943280216017`*^9, 3.661195376158166*^9, 3.662200534688282*^9, 
   3.69420033508062*^9, {3.694201375473606*^9, 3.694201496095849*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUV3c8Fl4Xt/d6Hg8KqWRkVBoUqXND0qB+kiQZhUqJSqVUdiRkJ8rIyt6y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     "]]}},
  AspectRatio->NCache[
    Rational[1, 4], 0.25],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Full,
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->
   NCache[{{0, 5 10^Rational[1, 2]}, {-1.568566741584297, 
     1.571311597208064}}, {{0, 15.811388300841898`}, {-1.568566741584297, 
     1.571311597208064}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, 
   3.661193627062294*^9, {3.661193685376652*^9, 3.661193703211871*^9}, 
   3.6611943280216017`*^9, 3.661195376158166*^9, 3.662200534688282*^9, 
   3.69420033508062*^9, {3.694201375473606*^9, 3.694201496208064*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solve the Equations of Motion:
Higher Frequency Drive - very strange\
\>", "Subsection",
 CellChangeTimes->{{3.661192395534131*^9, 3.661192407388399*^9}, {
  3.6611928211387577`*^9, 3.661192865383193*^9}, {3.661193284125386*^9, 
  3.661193284939232*^9}, {3.661193414953587*^9, 3.66119343431916*^9}, {
  3.6611935887812777`*^9, 3.6611936074181547`*^9}, {3.661193648939554*^9, 
  3.661193674487999*^9}, {3.6611937200810013`*^9, 3.661193742014243*^9}}],

Cell[TextData[{
 "Try different values of ",
 StyleBox["fd", "Input"],
 " and note how the stability and frequency of the \[Pi]/2 oscillations change"
}], "Text",
 CellChangeTimes->{{3.661195014344286*^9, 3.661195070752245*^9}, {
  3.6611952107756166`*^9, 3.661195256202414*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"g", "\[Rule]", "10"}], ",", 
     RowBox[{"l", "\[Rule]", "1"}], ",", 
     RowBox[{"ad", "\[Rule]", "0.2"}], ",", 
     RowBox[{"fd", "\[Rule]", "11"}], ",", 
     RowBox[{"phi0", "\[Rule]", 
      RowBox[{"\[Pi]", "/", "2"}]}], ",", 
     RowBox[{"v0", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{
    RowBox[{"5", " ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"g", "/", "l"}], "]"}]}], "/.", "pars"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eom", ",", "incon"}], "}"}], "//.", "pars"}], ",", "dvars", 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
    RowBox[{"MaxStepSize", "\[Rule]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"10", " ", "fd"}], ")"}]}], "/.", "pars"}], "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"phi", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"Evaluate", "[", "plotpars", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.660832934883301*^9, 3.6608329811674843`*^9}, {
  3.66083518203434*^9, 3.660835186864388*^9}, {3.6611924588876343`*^9, 
  3.6611924687916613`*^9}, {3.661192715248855*^9, 3.6611927435998173`*^9}, {
  3.661192902039855*^9, 3.6611929408869123`*^9}, {3.661193088336308*^9, 
  3.661193090829599*^9}, {3.661193152562392*^9, 3.661193214374984*^9}, {
  3.661193313245545*^9, 3.661193378312942*^9}, {3.661193438504074*^9, 
  3.661193458723958*^9}, {3.661193521301283*^9, 3.661193521351925*^9}, {
  3.661193613244508*^9, 3.661193624555544*^9}, {3.6611936799724407`*^9, 
  3.661193702626865*^9}, {3.661193745289027*^9, 3.661193777579794*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"phi", "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["InterpolatingFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA1try3Qb8kT6kJURU+yH5P9il3vII
f9A/Z15qeED18z8+EmxapDDhP/WZ9ol9Peg/5bzU8xGK6T9A4WcBiqXgPxtI
qgLJ3PA/6ebvjSnU7j9uAyEHV031P9wx9MqBcvU/bLTN5wty+T/k/4IVjMT4
PxU3McSO7/0/ToQD3Nx48D8JJ1BuDSwBQOpscOrlcOg/Xa2i6GY6A0CpDXgh
cmXeP4ec0GAndQVA1YVLAvTD8T+GhhlH+4kHQGUyPL5kufc/sDpoy1OUCUCu
8skZtvL3P69Xkk0TywtAWXDMq1KO6j+Db9c95tsNQDKLWT9Rfug/Fvj7FZAM
EEBRmdFwuUPhP4AdD1zvJRFAGkF/heW78z9VwC9ZWCwSQNvxkhBeAPk/lBc+
1fRIE0AWuzT3LR32Pz7sWQibUhRAqxMuu4r75j9TdWO6dHIVQE+06aWu8+c/
feNvuxCNFkBrD8OaloXlPxLPiXO2lBdAkAZIOtNJ9T8Rb5Gqj7IYQNv89zlg
Bvk/e4ymmHK9GUBP/4JlmOnzP/qOvtUXwxpAI0lZQf2y5T/kRcSR8N4bQKpj
0SXk6OU/OHrXBNPnHEDiL5/s1iTtP/di2PboBh5A3DGgaSXu9j/LMNw3wSAf
QGlhdTfsyfc/Bb72l9ETIECcdCNyuOTwP9k9dlNcoiBA9DSEUiHc4j9jfHzq
aychQPZwv8EbXuQ/dy0EqdypIUCyH53ewNHxP8G4AidnNyJAYnUqdPk2+D/A
AoiAdrsiQCSB+pbtGfc/9CaEmZ9KI0CmTvKneJ3qP94JB45N0CNAdn2XGYrC
5z9SXwuqXFMkQMXEVjpWgeE//I6GhYXhJEB5U8x98Df0P1t9iDwzZiVAuKqz
xjgd+T/vRQGz+vUlQNmrEuFpbfU/DoH7UCODJkBJFZT6wovkP+J6fMrQBidA
9sDCjXpf6D/sTnQDmJUnQG3x1LfRLuY/q+HyF+QaKEC1HM56nRX2P/Xm8lOR
nShALvq7lVwL+T90xmlPWCspQJQrUXDNuvM/qGRnJqSvKUCJUjBQU3zjPxHd
27wJPypAueQ6R8j85z8FyNF60MsqQJAz14iuh+s/rnFOFBxPK0Duy9ZWqjn3
P431QW2B3StAxeFaEE2F9z8hOLyha2IsQLYcseJjFvE/6lStlW/yLEC3v7lf
QC7gPz7kH7HUfy1AfbMNEX/86T9HMhmovgMuQKP6eni8VPE/hlqJXsKSLkDs
JdGpo834P3pBgPBKGC9Anwicnl889T+57pJAbp8vQNu/hwy2kOw/oazZCw==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0.35000000000000003`}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 15.811388300841898`}, {
                    0.4749417616696641, 1.570796326794473}}, 
                   PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "15.811388300841898`"}], "}"}], "}"}],
                     "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA1try3Qb8kT6kJURU+yH5P9il3vII
f9A/Z15qeED18z8+EmxapDDhP/WZ9ol9Peg/5bzU8xGK6T9A4WcBiqXgPxtI
qgLJ3PA/6ebvjSnU7j9uAyEHV031P9wx9MqBcvU/bLTN5wty+T/k/4IVjMT4
PxU3McSO7/0/ToQD3Nx48D8JJ1BuDSwBQOpscOrlcOg/Xa2i6GY6A0CpDXgh
cmXeP4ec0GAndQVA1YVLAvTD8T+GhhlH+4kHQGUyPL5kufc/sDpoy1OUCUCu
8skZtvL3P69Xkk0TywtAWXDMq1KO6j+Db9c95tsNQDKLWT9Rfug/Fvj7FZAM
EEBRmdFwuUPhP4AdD1zvJRFAGkF/heW78z9VwC9ZWCwSQNvxkhBeAPk/lBc+
1fRIE0AWuzT3LR32Pz7sWQibUhRAqxMuu4r75j9TdWO6dHIVQE+06aWu8+c/
feNvuxCNFkBrD8OaloXlPxLPiXO2lBdAkAZIOtNJ9T8Rb5Gqj7IYQNv89zlg
Bvk/e4ymmHK9GUBP/4JlmOnzP/qOvtUXwxpAI0lZQf2y5T/kRcSR8N4bQKpj
0SXk6OU/OHrXBNPnHEDiL5/s1iTtP/di2PboBh5A3DGgaSXu9j/LMNw3wSAf
QGlhdTfsyfc/Bb72l9ETIECcdCNyuOTwP9k9dlNcoiBA9DSEUiHc4j9jfHzq
aychQPZwv8EbXuQ/dy0EqdypIUCyH53ewNHxP8G4AidnNyJAYnUqdPk2+D/A
AoiAdrsiQCSB+pbtGfc/9CaEmZ9KI0CmTvKneJ3qP94JB45N0CNAdn2XGYrC
5z9SXwuqXFMkQMXEVjpWgeE//I6GhYXhJEB5U8x98Df0P1t9iDwzZiVAuKqz
xjgd+T/vRQGz+vUlQNmrEuFpbfU/DoH7UCODJkBJFZT6wovkP+J6fMrQBidA
9sDCjXpf6D/sTnQDmJUnQG3x1LfRLuY/q+HyF+QaKEC1HM56nRX2P/Xm8lOR
nShALvq7lVwL+T90xmlPWCspQJQrUXDNuvM/qGRnJqSvKUCJUjBQU3zjPxHd
27wJPypAueQ6R8j85z8FyNF60MsqQJAz14iuh+s/rnFOFBxPK0Duy9ZWqjn3
P431QW2B3StAxeFaEE2F9z8hOLyha2IsQLYcseJjFvE/6lStlW/yLEC3v7lf
QC7gPz7kH7HUfy1AfbMNEX/86T9HMhmovgMuQKP6eni8VPE/hlqJXsKSLkDs
JdGpo834P3pBgPBKGC9Anwicnl889T+57pJAbp8vQNu/hwy2kOw/oazZCw==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0.35000000000000003`}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, 
                   PlotRange -> {{0., 15.811388300841898`}, {
                    0.4749417616696641, 1.570796326794473}}, 
                   PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "15.811388300841898`"}], "}"}], "}"}],
                     "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->(
       "InterpolatingFunction[{{0., 15.8114}}, <>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, 
   3.661193627062294*^9, {3.661193685376652*^9, 3.661193703211871*^9}, {
   3.6611937470643682`*^9, 3.661193778333682*^9}, 3.661194328185762*^9, 
   3.661195376397057*^9, 3.662200534871126*^9, 3.694200335291555*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUV3c4Fe4Xt/e4l4uSUWbKShRS50VJ2auMMkoqK0pllCZJKYRUMkpI9TWK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     "]]}},
  AspectRatio->NCache[
    Rational[1, 4], 0.25],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.45},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Full,
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->
   NCache[{{0, 5 10^Rational[1, 2]}, {0.42921081690689383`, 
     1.5744993474453999`}}, {{0, 15.811388300841898`}, {0.42921081690689383`, 
     1.5744993474453999`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, 
   3.661193627062294*^9, {3.661193685376652*^9, 3.661193703211871*^9}, {
   3.6611937470643682`*^9, 3.661193778333682*^9}, 3.661194328185762*^9, 
   3.661195376397057*^9, 3.662200534871126*^9, 3.6942003353769493`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1279, 1192},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (June 27, \
2014)",
StyleDefinitions->FrontEnd`FileName[{"SlideShow"}, "Sapphire.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 151, 2, 141, "Section"],
Cell[CellGroupData[{
Cell[756, 28, 110, 1, 138, "Subsection"],
Cell[869, 31, 463, 11, 123, "Text"],
Cell[CellGroupData[{
Cell[1357, 46, 1240, 39, 119, "Input"],
Cell[2600, 87, 412, 8, 43, "Output"],
Cell[3015, 97, 1027, 27, 64, "Output"]
}, Open  ]],
Cell[4057, 127, 166, 2, 59, "Text"],
Cell[CellGroupData[{
Cell[4248, 133, 1023, 31, 119, "Input"],
Cell[5274, 166, 656, 17, 43, "Output"],
Cell[5933, 185, 659, 17, 43, "Output"],
Cell[6595, 204, 1011, 27, 43, "Output"],
Cell[7609, 233, 739, 20, 43, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8397, 259, 311, 6, 182, "Subsection"],
Cell[8711, 267, 210, 3, 59, "Text"],
Cell[8924, 272, 237, 5, 43, "Input"],
Cell[9164, 279, 174, 2, 59, "Text"],
Cell[9341, 283, 1135, 35, 94, "Input"],
Cell[10479, 320, 367, 10, 251, "Text"],
Cell[10849, 332, 1258, 29, 69, "Input"],
Cell[12110, 363, 291, 7, 91, "Text"],
Cell[CellGroupData[{
Cell[12426, 374, 771, 20, 69, "Input"],
Cell[13200, 396, 11941, 230, 72, "Output"]
}, Open  ]],
Cell[25156, 629, 287, 6, 59, "Text"],
Cell[CellGroupData[{
Cell[25468, 639, 768, 19, 69, "Input"],
Cell[26239, 660, 51914, 864, 278, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[78202, 1530, 301, 6, 182, "Subsection"],
Cell[78506, 1538, 162, 5, 59, "Text"],
Cell[CellGroupData[{
Cell[78693, 1547, 2080, 53, 144, "Input"],
Cell[80776, 1602, 12043, 232, 72, "Output"],
Cell[92822, 1836, 53249, 886, 281, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[146120, 2728, 303, 6, 182, "Subsection"],
Cell[146426, 2736, 206, 5, 59, "Text"],
Cell[CellGroupData[{
Cell[146657, 2745, 2029, 52, 144, "Input"],
Cell[148689, 2799, 11939, 231, 72, "Output"],
Cell[160631, 3032, 52990, 882, 283, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[213670, 3920, 408, 8, 182, "Subsection"],
Cell[214081, 3930, 283, 7, 91, "Text"],
Cell[CellGroupData[{
Cell[214389, 3941, 2178, 54, 144, "Input"],
Cell[216570, 3997, 11987, 231, 72, "Output"],
Cell[228560, 4230, 24701, 418, 285, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[253310, 4654, 452, 8, 182, "Subsection"],
Cell[CellGroupData[{
Cell[253787, 4666, 2021, 52, 144, "Input"],
Cell[255811, 4720, 11921, 230, 72, "Output"],
Cell[267735, 4952, 63051, 1047, 283, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[330835, 6005, 459, 8, 182, "Subsection"],
Cell[331297, 6015, 279, 6, 91, "Text"],
Cell[CellGroupData[{
Cell[331601, 6025, 2019, 52, 144, "Input"],
Cell[333623, 6079, 11930, 229, 72, "Output"],
Cell[345556, 6310, 62748, 1042, 296, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
