(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    217395,       3849]
NotebookOptionsPosition[    215943,       3799]
NotebookOutlinePosition[    216367,       3816]
CellTagsIndexPosition[    216324,       3813]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Numerical Integration of Equations of Motion", "Section",
 CellChangeTimes->{{3.660832414776634*^9, 3.66083244909306*^9}}],

Cell["List dependent variables", "Text",
 CellChangeTimes->{{3.660832456879169*^9, 3.6608324600056953`*^9}, {
  3.660832835692389*^9, 3.6608328397141047`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dvars", "=", 
   RowBox[{"{", "phi", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.660832483703415*^9, 3.660832584660935*^9}, 
   3.660832764596962*^9, {3.6608328603805437`*^9, 3.660832875412587*^9}}],

Cell["Write equations of motion", "Text",
 CellChangeTimes->{{3.660832456879169*^9, 3.6608324600056953`*^9}, {
  3.660832842858343*^9, 3.660832856561316*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"phi", "''"}], "[", "t", "]"}], "\[Equal]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", " ", 
         RowBox[{
          RowBox[{"w", "^", "2"}], "/", "l"}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"phi", "[", "t", "]"}], " ", "-", " ", 
         RowBox[{"w", " ", "t"}]}], "]"}]}], " ", "-", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"g", "/", "l"}], ")"}], 
       RowBox[{"Sin", "[", 
        RowBox[{"phi", "[", "t", "]"}], "]"}]}]}]}], "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.660832483703415*^9, 3.660832584660935*^9}, 
   3.660832764596962*^9, {3.660835010207456*^9, 3.660835010264978*^9}}],

Cell["Define all parameters", "Text",
 CellChangeTimes->{{3.660832915122074*^9, 3.660832921143371*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"l", "\[Rule]", "2"}], ",", 
     RowBox[{"w", "\[Rule]", "10"}], ",", 
     RowBox[{"g", "\[Rule]", "9.8"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", "2"}], ";"}]}], "Input",
 CellChangeTimes->{{3.660832934883301*^9, 3.6608329811674843`*^9}, {
  3.66083518203434*^9, 3.660835186864388*^9}}],

Cell["Add some initial condisions", "Text",
 CellChangeTimes->{{3.660832681260478*^9, 3.660832687766308*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"incon", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"phi", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"phi", "'"}], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6608326954929867`*^9, 3.660832751006125*^9}}],

Cell["Solve with NDSolve", "Text",
 CellChangeTimes->{{3.660832600511394*^9, 3.66083260568856*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eom", ",", "incon"}], "}"}], "//.", "pars"}], ",", "dvars", 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.660832619090395*^9, 3.660832660968112*^9}, {
  3.660832800013995*^9, 3.660832815099805*^9}, {3.660832885950898*^9, 
  3.660832895810577*^9}, {3.660832987215814*^9, 3.660832999807445*^9}, {
  3.660835197920516*^9, 3.660835198731563*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"phi", "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["InterpolatingFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAotpLlPIyYj4AwHuVDAciPXzLgjFp
saA/bHtNm7f7mj8zeMj4ImWxP0St5UFolbw/TO2n0Q/YuT8sE7vpOYDOP/lc
W4xHEME/sELykPeL2T/5Y1FcZI7FP6fYVQ4QaOM/S5yzaMC/yT9Id6cXxljq
P0p1hKH5Ss4/nvEeY3A58T8IfbYIfmDRP1XA2mjrY/U/FNjg3h510z/swTza
5Fz5P3aDQkuuttU/3j2VzI+v/T+BR9pV3dHXP2ru17CZ1QBAb+H9+3Di2T9C
1YMOT7sCQLTLWDjzH9w/Wbdxzp2xBECizukSFTfePxYsxEwFZgZA8xDZwZI9
4D+j/ULyJxAIQIYlA0hNWuE/KdXLZVB1CUBuRkid12PiP2rRFDnlfQpAgQ+p
PdmD4z+NMWXH90ELQOnkJK2qkOQ/n0NpTsWVC0B8Yrxn87PlP4kt9r06egtA
AMsZcO7R5j/cyS5gEekKQNk/kke53Oc/GrOY0toJCkDdXCZq+/3oP5MFpTrZ
3whANobVWw0M6j/yv7H8ucYHQICaSpvRFOs/ysGMmJvfBkD1VtslDTTsP4cq
wuHVPgZAvx+HfxhA7T9gVbXFLhEGQLSQTiSbYu4/ZXOx0jNVBkCb7NsW0H/v
P3b5n3mvBQdAbCpCbOpE8D+80ZL2ff4HQJ8ypHIo1fA/i8qbwnRXCUD9wJNg
zlvxP9wFDrJN0QpA00Rmdc3f8T/sOr4GpWsMQL+cxi8Ib/I/qgGz7nBJDkDV
erTRqvTyP626D/zFDRBAAS0wGYmF8z8K4StnIxARQFdlOUjPDPQ/BbJ8Y+cB
EkAmkyWebpH0P31L3fuo6hJAC5WfmUkh9T/Zbf1AjdwTQBodp3yMp/U/NYJU
iU2uFEA+eTwFCzn2P0cesUR3eBVA28q0tOLH9j9JepwP7hwWQKKiuksiTfc/
R5zxovGPFkB/Tk6Ind33P37kIbCL2hZAhoBvrIBk+D9JE3BxnOsWQAaoc/e8
6Pg/NvZ/3/bJFkCcowXoNHj5P7Ec5FZmcxZAXCUlwBT++T9dFyBrRgIWQDJ7
0j0wj/o/wsXcbo19FUCAxmLipB37Pw4Qh5niDRVA+ZeAboGi+z9YD6zAvswU
QIc9LKCZMvw/MJZbNXzAFEBAaWW5Gbn8P0surPYc8hRADmkseNVK/T9tYyX5
aGoVQFVe1l3q2f0/RudX7sUfFkDG2Q0rZ1/+P2Hacv6e/BZATSnTnR/w/j+h
V1kfPx8YQP7+Jfg/d/8/sC0RINZaGUC2hub2////P36QzkQYwxpAds3RCQ==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 2.}, {0., 6.690522265536968}}, 
                   PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "2.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAotpLlPIyYj4AwHuVDAciPXzLgjFp
saA/bHtNm7f7mj8zeMj4ImWxP0St5UFolbw/TO2n0Q/YuT8sE7vpOYDOP/lc
W4xHEME/sELykPeL2T/5Y1FcZI7FP6fYVQ4QaOM/S5yzaMC/yT9Id6cXxljq
P0p1hKH5Ss4/nvEeY3A58T8IfbYIfmDRP1XA2mjrY/U/FNjg3h510z/swTza
5Fz5P3aDQkuuttU/3j2VzI+v/T+BR9pV3dHXP2ru17CZ1QBAb+H9+3Di2T9C
1YMOT7sCQLTLWDjzH9w/Wbdxzp2xBECizukSFTfePxYsxEwFZgZA8xDZwZI9
4D+j/ULyJxAIQIYlA0hNWuE/KdXLZVB1CUBuRkid12PiP2rRFDnlfQpAgQ+p
PdmD4z+NMWXH90ELQOnkJK2qkOQ/n0NpTsWVC0B8Yrxn87PlP4kt9r06egtA
AMsZcO7R5j/cyS5gEekKQNk/kke53Oc/GrOY0toJCkDdXCZq+/3oP5MFpTrZ
3whANobVWw0M6j/yv7H8ucYHQICaSpvRFOs/ysGMmJvfBkD1VtslDTTsP4cq
wuHVPgZAvx+HfxhA7T9gVbXFLhEGQLSQTiSbYu4/ZXOx0jNVBkCb7NsW0H/v
P3b5n3mvBQdAbCpCbOpE8D+80ZL2ff4HQJ8ypHIo1fA/i8qbwnRXCUD9wJNg
zlvxP9wFDrJN0QpA00Rmdc3f8T/sOr4GpWsMQL+cxi8Ib/I/qgGz7nBJDkDV
erTRqvTyP626D/zFDRBAAS0wGYmF8z8K4StnIxARQFdlOUjPDPQ/BbJ8Y+cB
EkAmkyWebpH0P31L3fuo6hJAC5WfmUkh9T/Zbf1AjdwTQBodp3yMp/U/NYJU
iU2uFEA+eTwFCzn2P0cesUR3eBVA28q0tOLH9j9JepwP7hwWQKKiuksiTfc/
R5zxovGPFkB/Tk6Ind33P37kIbCL2hZAhoBvrIBk+D9JE3BxnOsWQAaoc/e8
6Pg/NvZ/3/bJFkCcowXoNHj5P7Ec5FZmcxZAXCUlwBT++T9dFyBrRgIWQDJ7
0j0wj/o/wsXcbo19FUCAxmLipB37Pw4Qh5niDRVA+ZeAboGi+z9YD6zAvswU
QIc9LKCZMvw/MJZbNXzAFEBAaWW5Gbn8P0surPYc8hRADmkseNVK/T9tYyX5
aGoVQFVe1l3q2f0/RudX7sUfFkDG2Q0rZ1/+P2Hacv6e/BZATSnTnR/w/j+h
V1kfPx8YQP7+Jfg/d/8/sC0RINZaGUC2hub2////P36QzkQYwxpAds3RCQ==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 2.}, {0., 6.690522265536968}}, 
                   PlotRangeClipping -> True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "2.`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->("InterpolatingFunction[{{0., 2.}}, <>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.660833005811377*^9, 3.660835018027557*^9, 
  3.660835201534309*^9}]
}, Open  ]],

Cell["Plot the solution", "Text",
 CellChangeTimes->{{3.660833012250332*^9, 3.660833016253186*^9}, {
  3.660833109260655*^9, 3.660833112850033*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"phi", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.660833035223577*^9, 3.660833073597073*^9}, {
  3.6608352042179747`*^9, 3.660835205392108*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV13c81G8cAHChu+OojLvwMzKSZKSQVD6PlpSRjFQoKREpIxIiKyRRZqRh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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 2}, {0., 6.6905221885807915`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.660833076956625*^9, 3.66083501808286*^9, 
  3.6608352058026543`*^9}]
}, Open  ]],

Cell["or plot in some other coordinates", "Text",
 CellChangeTimes->{{3.660833121056897*^9, 3.660833127706257*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xy", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{
       RowBox[{"a", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"w", " ", "t"}], "]"}]}], " ", "+", " ", 
       RowBox[{"l", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"phi", "[", "t", "]"}], "]"}]}]}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"w", " ", "t"}], "]"}]}], " ", "+", " ", 
       RowBox[{"l", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"phi", "[", "t", "]"}], "]"}]}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], "/.", "xy"}], "/.", "pars"}], "/.", 
     "sol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "y"}]}], "}"}], "/.", "xy"}], "/.", "pars"}], "/.", 
     "sol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.660833137385584*^9, 3.660833316765983*^9}, {
   3.660833360918989*^9, 3.660833369718371*^9}, 3.660833417696651*^9, {
   3.660835210797894*^9, 3.6608352116454*^9}, {3.660835250117659*^9, 
   3.660835251092512*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwd13c8ld8fAPB7b4WQlMhKSBJCRXw1PlJJVkYqpBQle6SyGsrKykpkr4wQ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     "]]}, 
   {RGBColor[0.985248, 0.676238, 0.0398315], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwVmXk8VN8bx8c6LaikQrIViURFiXimQpGURJJkKUWSLRVKKVupkMqeLUsk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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 2}, {-2.9980829043315755`, 2.0084173867117268`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.660833317740562*^9, 3.660833370544033*^9, 
  3.6608334186013412`*^9, 3.660835018155737*^9, 3.660835212164536*^9, 
  3.660835251473881*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwt13k8VN//OPAZZJA2VIoKFYWkkkR1JluylUJlT8qSQilaUEJSSZQ3siYS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     "]]}},
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"ScalingFunctions" -> None},
  PlotRange->{{-2.26701069392324, 1.2004139272820844`}, {-2.0084173863432997`,
    2.9980829047089155`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.660833317740562*^9, 3.660833370544033*^9, 
  3.6608334186013412`*^9, 3.660835018155737*^9, 3.660835212164536*^9, 
  3.660835251539646*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Try again, with different parameters and initial conditions", \
"Subsection",
 CellChangeTimes->{{3.66083372901851*^9, 3.660833737256963*^9}, {
  3.660833868335042*^9, 3.66083386908497*^9}, {3.660833899196027*^9, 
  3.66083390076406*^9}, {3.6608353379269*^9, 3.6608353411545343`*^9}, {
  3.660835425450534*^9, 3.660835442863413*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "1"}], ",", 
     RowBox[{"l", "\[Rule]", "2"}], ",", 
     RowBox[{"w", "\[Rule]", "0.3"}], ",", 
     RowBox[{"g", "\[Rule]", "9.8"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{
    RowBox[{"4", " ", 
     RowBox[{"\[Pi]", "/", "w"}]}], "/.", "pars"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"incon", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"phi", "[", "0", "]"}], "\[Equal]", "0.1"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"phi", "'"}], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"eom", ",", "incon"}], "}"}], "//.", "pars"}], ",", "dvars", 
     ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"phi", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"w", " ", 
            RowBox[{"t", "/", 
             RowBox[{"(", 
              RowBox[{"2", " ", "\[Pi]"}], ")"}]}]}], ",", "x"}], "}"}], "/.",
          "xy"}], "/.", "pars"}], "/.", "sol"}], "]"}], ",", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"w", " ", 
            RowBox[{"t", "/", 
             RowBox[{"(", 
              RowBox[{"2", " ", "\[Pi]"}], ")"}]}]}], ",", "y"}], "}"}], "/.",
          "xy"}], "/.", "pars"}], "/.", "sol"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "y"}]}], "}"}], "/.", "xy"}], "/.", "pars"}], "/.", 
     "sol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.660832619090395*^9, 3.660832660968112*^9}, {
  3.660832800013995*^9, 3.660832815099805*^9}, {3.660832885950898*^9, 
  3.660832895810577*^9}, {3.660832987215814*^9, 3.660832999807445*^9}, {
  3.6608337967066936`*^9, 3.660833896189389*^9}, {3.6608340107257032`*^9, 
  3.660834022708807*^9}, {3.6608341499955187`*^9, 3.6608342798941174`*^9}, {
  3.660834310831854*^9, 3.660834368265291*^9}, {3.6608344102906923`*^9, 
  3.6608344103861513`*^9}, {3.660834442977439*^9, 3.6608346514236193`*^9}, {
  3.6608346912398653`*^9, 3.660834718116354*^9}, {3.660835041861313*^9, 
  3.660835081404097*^9}, {3.660835112723522*^9, 3.660835134093318*^9}, {
  3.660835359781536*^9, 3.660835388941524*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUl3c81d8fx8ke2aOsyN7ce6mE886IJDOFijIjSYWQkIivWVG2jOx9t9VR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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 41.88790204786391}, {-0.09993946481627296, 
    0.09999999999983153}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.660833825279828*^9, 3.660833842790851*^9}, 
   3.660833872865855*^9, 3.6608339053291817`*^9, {3.6608340119087477`*^9, 
   3.660834023215932*^9}, 3.66083415544759*^9, {3.660834227236967*^9, 
   3.660834246469137*^9}, 3.6608342817863617`*^9, {3.660834321264243*^9, 
   3.660834369319379*^9}, 3.660834411316716*^9, {3.6608345158060083`*^9, 
   3.660834542512826*^9}, {3.660834636114443*^9, 3.660834652040969*^9}, {
   3.660834693017651*^9, 3.660834718376655*^9}, {3.660835018277422*^9, 
   3.6608350819785137`*^9}, {3.6608351182493477`*^9, 3.660835134476458*^9}, {
   3.660835366610169*^9, 3.660835389577263*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw8d3k81N/3v1SSUlosWZISKpU1KTkoJClRlpI1VJK1kIQ2JWlDCpEta9lC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     "]]}, 
   {RGBColor[0.985248, 0.676238, 0.0398315], AbsoluteThickness[1.6], Opacity[
    1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJw1mnk8VP/3x61zRYulEC1EQkipJOW8VWRJhCIiRFFpQSlLqZSlhZCEFFki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     "]]}},
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"ScalingFunctions" -> None},
  PlotRange->{{0., 2.}, {-1.1892939482330354`, 2.996376413925293}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.660833825279828*^9, 3.660833842790851*^9}, 
   3.660833872865855*^9, 3.6608339053291817`*^9, {3.6608340119087477`*^9, 
   3.660834023215932*^9}, 3.66083415544759*^9, {3.660834227236967*^9, 
   3.660834246469137*^9}, 3.6608342817863617`*^9, {3.660834321264243*^9, 
   3.660834369319379*^9}, 3.660834411316716*^9, {3.6608345158060083`*^9, 
   3.660834542512826*^9}, {3.660834636114443*^9, 3.660834652040969*^9}, {
   3.660834693017651*^9, 3.660834718376655*^9}, {3.660835018277422*^9, 
   3.6608350819785137`*^9}, {3.6608351182493477`*^9, 3.660835134476458*^9}, {
   3.660835366610169*^9, 3.660835389670951*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], FaceForm[Opacity[0.3]], LineBox[CompressedData["
1:eJwUl3c81f8Xx69r3FDRQElkZJQyC6nekRFSkRBSiVSIJlJpyEppWZlFvjIK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     "]]}},
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, -3.},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"ScalingFunctions" -> None},
  PlotRange->{{-1.1892939482330354`, 
   1.1996668332936564`}, {-2.996376413925293, -0.9960593698762525}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.660833825279828*^9, 3.660833842790851*^9}, 
   3.660833872865855*^9, 3.6608339053291817`*^9, {3.6608340119087477`*^9, 
   3.660834023215932*^9}, 3.66083415544759*^9, {3.660834227236967*^9, 
   3.660834246469137*^9}, 3.6608342817863617`*^9, {3.660834321264243*^9, 
   3.660834369319379*^9}, 3.660834411316716*^9, {3.6608345158060083`*^9, 
   3.660834542512826*^9}, {3.660834636114443*^9, 3.660834652040969*^9}, {
   3.660834693017651*^9, 3.660834718376655*^9}, {3.660835018277422*^9, 
   3.6608350819785137`*^9}, {3.6608351182493477`*^9, 3.660835134476458*^9}, {
   3.660835366610169*^9, 3.66083538976792*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 911},
WindowMargins->{{Automatic, 462}, {Automatic, 196}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (June 27, \
2014)",
StyleDefinitions->FrontEnd`FileName[{"SlideShow"}, "Sapphire.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 128, 1, 184, "Section"],
Cell[711, 25, 159, 2, 59, "Text"],
Cell[873, 29, 237, 5, 43, "Input"],
Cell[1113, 36, 158, 2, 59, "Text"],
Cell[1274, 40, 793, 24, 94, "Input"],
Cell[2070, 66, 103, 1, 59, "Text"],
Cell[2176, 69, 459, 12, 69, "Input"],
Cell[2638, 83, 109, 1, 59, "Text"],
Cell[2750, 86, 348, 11, 43, "Input"],
Cell[3101, 99, 99, 1, 59, "Text"],
Cell[CellGroupData[{
Cell[3225, 104, 540, 13, 43, "Input"],
Cell[3768, 119, 11452, 222, 72, "Output"]
}, Open  ]],
Cell[15235, 344, 148, 2, 59, "Text"],
Cell[CellGroupData[{
Cell[15408, 350, 356, 9, 43, "Input"],
Cell[15767, 361, 15313, 263, 256, "Output"]
}, Open  ]],
Cell[31095, 627, 115, 1, 59, "Text"],
Cell[CellGroupData[{
Cell[31235, 632, 1606, 50, 144, "Input"],
Cell[32844, 684, 21387, 363, 243, "Output"],
Cell[54234, 1049, 15047, 258, 454, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69318, 1312, 339, 5, 208, "Subsection"],
Cell[CellGroupData[{
Cell[69682, 1321, 3223, 94, 319, "Input"],
Cell[72908, 1417, 42234, 702, 235, "Output"],
Cell[115145, 2121, 56921, 943, 454, "Output"],
Cell[172069, 3066, 43834, 728, 368, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
