(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    399951,       7212]
NotebookOptionsPosition[    397204,       7120]
NotebookOutlinePosition[    397625,       7137]
CellTagsIndexPosition[    397582,       7134]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["The Vertically Driven Pendulum", "Section",
 CellChangeTimes->{{3.660832414776634*^9, 3.66083244909306*^9}, {
  3.66119258412182*^9, 3.661192589991214*^9}, {3.66129320807115*^9, 
  3.661293210268175*^9}}],

Cell[CellGroupData[{

Cell["Solving the Lagrangian", "Subsection",
 CellChangeTimes->{{3.661192087423953*^9, 3.661192093013431*^9}}],

Cell[TextData[{
 "Setup the problem with Potential Energy (U) and Kinetic Energy (T)\nThe \
pendulum suport point moves as a function of time, ",
 StyleBox["yd[t]", "Input"],
 ".  The coordinates of the pendulum mass are ",
 StyleBox["xm", "Input"],
 " and ",
 StyleBox["ym.", "Input"]
}], "Text",
 CellChangeTimes->{{3.661192131929822*^9, 3.661192162037263*^9}, {
  3.661192605026491*^9, 3.661192638925995*^9}, {3.661195314020802*^9, 
  3.6611953630472937`*^9}, {3.6612949180071077`*^9, 3.661294926395266*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"xm", "[", "t", "]"}], "=", 
   RowBox[{"l", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"phi", "[", "t", "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ym", "[", "t", "]"}], "=", 
   RowBox[{
    RowBox[{"yd", "[", "t", "]"}], "-", 
    RowBox[{"l", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"U", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"m", " ", "g", " ", 
    RowBox[{"ym", "[", "t", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"T", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], " ", "m", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"xm", "[", "t", "]"}], ",", "t"}], "]"}], "^", "2"}], "+", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"ym", "[", "t", "]"}], ",", "t"}], "]"}], "^", "2"}]}], 
     ")"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6611921105715637`*^9, 3.661192123943734*^9}, 
   3.661192177209876*^9, {3.6611922593162317`*^9, 3.6611922883056602`*^9}, {
   3.661293295843897*^9, 3.6612933277543507`*^9}}],

Cell[BoxData[
 RowBox[{"g", " ", "m", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "l"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}]}], "+", 
    RowBox[{"yd", "[", "t", "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.661192279740629*^9, 3.661192288568173*^9}, 
   3.661192656179741*^9, 3.66119295489567*^9, {3.6611931724627323`*^9, 
   3.6611932413045883`*^9}, 3.661194326805313*^9, 3.6611953743912983`*^9, {
   3.6612933218210993`*^9, 3.6612933297033243`*^9}, 3.661293409209997*^9, 
   3.661294357068871*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "m", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["l", "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["phi", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"2", " ", "l", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["phi", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["yd", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["yd", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.661192279740629*^9, 3.661192288568173*^9}, 
   3.661192656179741*^9, 3.66119295489567*^9, {3.6611931724627323`*^9, 
   3.6611932413045883`*^9}, 3.661194326805313*^9, 3.6611953743912983`*^9, {
   3.6612933218210993`*^9, 3.6612933297033243`*^9}, 3.661293409209997*^9, 
   3.6612943570797043`*^9}]
}, Open  ]],

Cell["Solve the Euler-Lagrange Equation, with Damping Term", "Text",
 CellChangeTimes->{{3.661192190740988*^9, 3.6611921970584297`*^9}, {
  3.661192233753406*^9, 3.661192234897395*^9}, {3.6612948900041533`*^9, 
  3.6612948986839333`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Fphi", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"T", "-", "U"}], ",", 
      RowBox[{"phi", "[", "t", "]"}]}], "]"}], "]"}], "-", 
   RowBox[{"b", " ", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"phi", "[", "t", "]"}], ",", "t"}], 
     "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"pphi", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"T", "-", "U"}], ",", 
     RowBox[{
      RowBox[{"phi", "'"}], "[", "t", "]"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"dpphi", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"D", "[", 
    RowBox[{"pphi", ",", "t"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"eomd", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Fphi", "\[Equal]", "dpphi"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"m", ">", "0"}], ",", 
       RowBox[{"l", ">", "0"}]}], "}"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{
  3.661192250685864*^9, {3.661192340977541*^9, 3.6611923470237007`*^9}, {
   3.661192908649427*^9, 3.661192930895393*^9}, {3.6612939646594133`*^9, 
   3.661293982566588*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "b"}], " ", 
   RowBox[{
    SuperscriptBox["phi", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"l", " ", "m", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "g"}], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"phi", "[", "t", "]"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["phi", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["yd", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.6611923510298557`*^9, 3.66119265640351*^9, 3.661192955152038*^9, {
   3.6611931727785892`*^9, 3.661193241575959*^9}, 3.6611943271038218`*^9, 
   3.661195374767346*^9, 3.661293343174011*^9, 3.66129340949111*^9, 
   3.661293986804164*^9, 3.661294357388568*^9}],

Cell[BoxData[
 RowBox[{"l", " ", "m", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"l", " ", 
     RowBox[{
      SuperscriptBox["phi", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["yd", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.6611923510298557`*^9, 3.66119265640351*^9, 3.661192955152038*^9, {
   3.6611931727785892`*^9, 3.661193241575959*^9}, 3.6611943271038218`*^9, 
   3.661195374767346*^9, 3.661293343174011*^9, 3.66129340949111*^9, 
   3.661293986804164*^9, 3.661294357400399*^9}],

Cell[BoxData[
 RowBox[{"l", " ", "m", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["phi", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["yd", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"l", " ", 
     RowBox[{
      SuperscriptBox["phi", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["yd", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.6611923510298557`*^9, 3.66119265640351*^9, 3.661192955152038*^9, {
   3.6611931727785892`*^9, 3.661193241575959*^9}, 3.6611943271038218`*^9, 
   3.661195374767346*^9, 3.661293343174011*^9, 3.66129340949111*^9, 
   3.661293986804164*^9, 3.661294357411789*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"b", " ", 
    RowBox[{
     SuperscriptBox["phi", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "+", 
   RowBox[{"l", " ", "m", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"l", " ", 
       RowBox[{
        SuperscriptBox["phi", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Sin", "[", 
        RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"g", "+", 
         RowBox[{
          SuperscriptBox["yd", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], ")"}]}]}], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{
  3.6611923510298557`*^9, 3.66119265640351*^9, 3.661192955152038*^9, {
   3.6611931727785892`*^9, 3.661193241575959*^9}, 3.6611943271038218`*^9, 
   3.661195374767346*^9, 3.661293343174011*^9, 3.66129340949111*^9, 
   3.661293986804164*^9, 3.661294357519761*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve the Equations of Motion", "Subsection",
 CellChangeTimes->{{3.661192395534131*^9, 3.661192407388399*^9}, {
   3.6611928211387577`*^9, 3.6611928371361322`*^9}, {3.66119493146782*^9, 
   3.6611949345478277`*^9}, {3.6612948783825207`*^9, 3.661294882604233*^9}, 
   3.661295274828431*^9}],

Cell["List dependent variables", "Text",
 CellChangeTimes->{{3.660832456879169*^9, 3.6608324600056953`*^9}, {
  3.660832835692389*^9, 3.6608328397141047`*^9}, {3.661192066297888*^9, 
  3.6611920689822903`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dvars", "=", 
   RowBox[{"{", "phi", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.660832483703415*^9, 3.660832584660935*^9}, 
   3.660832764596962*^9, {3.6608328603805437`*^9, 3.660832875412587*^9}}],

Cell["Set initial condisions and drive function", "Text",
 CellChangeTimes->{{3.660832681260478*^9, 3.660832687766308*^9}, {
  3.6611930032855873`*^9, 3.661193061977792*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"incon", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"phi", "[", "0", "]"}], "\[Equal]", "phi0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"phi", "'"}], "[", "0", "]"}], "\[Equal]", "v0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y1", "[", "t", "]"}], "=", 
   RowBox[{"ad", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"fd", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"g", "/", "l"}], "]"}], " ", "t"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"eom", "=", 
  RowBox[{"eomd", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"yd", "''"}], "[", "t", "]"}], "\[Rule]", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"y1", "[", "t", "]"}], ",", "t"}], "]"}], ",", "t"}], 
      "]"}]}], "}"}]}]}]}], "Input",
 CellChangeTimes->{{3.6608326954929867`*^9, 3.660832751006125*^9}, {
   3.661193056669105*^9, 3.661193057100478*^9}, {3.66119312046727*^9, 
   3.66119314712897*^9}, {3.661193235464512*^9, 3.661193236134149*^9}, {
   3.661293373691227*^9, 3.661293381241584*^9}, 3.6612934857908373`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"b", " ", 
    RowBox[{
     SuperscriptBox["phi", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], "+", 
   RowBox[{"l", " ", "m", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"g", "-", 
         FractionBox[
          RowBox[{"ad", " ", 
           SuperscriptBox["fd", "2"], " ", "g", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"fd", " ", 
             SqrtBox[
              FractionBox["g", "l"]], " ", "t"}], "]"}]}], "l"]}], ")"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"phi", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{"l", " ", 
       RowBox[{
        SuperscriptBox["phi", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], "\[Equal]",
   "0"}]], "Output",
 CellChangeTimes->{3.661293487320958*^9, 3.661294004327632*^9, 
  3.661294357590046*^9}]
}, Open  ]],

Cell["Define all parameters", "Text",
 CellChangeTimes->{{3.660832915122074*^9, 3.660832921143371*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"m", "\[Rule]", "1"}], ",", 
     RowBox[{"g", "\[Rule]", "10"}], ",", 
     RowBox[{"l", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "0.1"}], ",", 
     RowBox[{"ad", "\[Rule]", "0"}], ",", 
     RowBox[{"fd", "\[Rule]", "0.1"}], ",", 
     RowBox[{"phi0", "\[Rule]", "0.1"}], ",", 
     RowBox[{"v0", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{
    RowBox[{"30", " ", "2", 
     RowBox[{"\[Pi]", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"g", "/", "l"}], "]"}]}]}], "/.", "pars"}]}], ";"}]}], "Input",\

 CellChangeTimes->{{3.660832934883301*^9, 3.6608329811674843`*^9}, {
  3.66083518203434*^9, 3.660835186864388*^9}, {3.6611924588876343`*^9, 
  3.6611924687916613`*^9}, {3.661192715248855*^9, 3.6611927435998173`*^9}, {
  3.661192902039855*^9, 3.6611929408869123`*^9}, {3.661193088336308*^9, 
  3.661193090829599*^9}, {3.661193152562392*^9, 3.661193214374984*^9}, {
  3.661194304467681*^9, 3.661194316351289*^9}, {3.6612935564034977`*^9, 
  3.6612935840511913`*^9}, {3.6612940121568527`*^9, 3.661294037344441*^9}, {
  3.661294144229828*^9, 3.661294153295735*^9}, {3.6612941893130302`*^9, 
  3.661294190646474*^9}, {3.661294242612617*^9, 3.661294287057358*^9}, {
  3.6612943300206747`*^9, 3.661294332110108*^9}}],

Cell["Solve with NDSolve", "Text",
 CellChangeTimes->{{3.660832600511394*^9, 3.66083260568856*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eom", ",", "incon"}], "}"}], "//.", "pars"}], ",", "dvars", 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
    RowBox[{"MaxStepSize", "\[Rule]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"10", " ", "fd"}], ")"}]}], "/.", "pars"}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.660832619090395*^9, 3.660832660968112*^9}, {
   3.660832800013995*^9, 3.660832815099805*^9}, {3.660832885950898*^9, 
   3.660832895810577*^9}, {3.660832987215814*^9, 3.660832999807445*^9}, {
   3.660835197920516*^9, 3.660835198731563*^9}, 3.661192505638955*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"phi", "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["InterpolatingFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAfgkCbDHzsD5UAJmZmZm5PxSyN707
GO8/ZvmDTupLuL/0W4XjgTMAQF4QNHb8BLc/0ix/ZfwRCEBtmJKErvm1v2lD
JsryyA9Agvn+hDn7tD8lNKjdphMUQPv5fz9burO/TXceHVj7F0A1bLH5m+ey
P5pB1qK7NhxAXOMaF+JDsb9iV/KMLi8gQJDsvgzDGK8/UybqK0EfIkAOQnCq
bZiuv9a4Au4sOSRArpjjuJauqj+144uTWi8mQFMuk96X/am/AmDAMacbKECD
ElYasPmpP+KfFfPMMSpA5+bHUoLMpr8deNuXNCQsQM57z77mgaY/6xPCX3VA
LkBncMNYxNGiv5QAKpBqKTBAMEQbNRGmnz9gQytiuyAxQG7xKXkJY6C/9ue8
xfgsMkC+/cIsTAeaP7rYBhtXJzNA7alClDdEmr9HK+EBojY0QMcE4bIdn5I/
iyYRZfxANUDeNePg2e+Jv/1t+bl3OTZAMneYNA80jT84F3Kg30Y3QAqVD/lg
l4C/oQyjeGhCOECCR5VIp9iBP8GqKc0AOTlAfkpqe2U/hr+qqkCzhUQ6QOrF
jXdHOnk/wfYPiys+O0Aub9Bldu99v6Kkb/S9TDxAQjDFB8S9YT86+yTaX1Y9
QDJIFh/J1VI/AJ6SsSJOPkAmPcqZitFGP4+ikBrSWj9ARBfYIje1aD+meaM6
0SpAQCsO7jdhc2C/X3YpJsGlQECQPyAm3nIRv/2jd1onK0FAruh+vZH/Zb+y
96EHnqdBQBo3l8BIOVc/THyU/YouQkAwYG8QHwFyv/0mY2yIrEJA6Ncp74Su
bj8JplyZDShDQOxxOO5EjWK/+lUeDwmuQ0BJaDuHtyJyPwIsvP0UK0RAnAD2
CksMbb/uMiI1l7JEQMr/buCeqXc/Ng6zKqE3RUByQfYonIV8v5UPIJm7s0VA
FBvdu5U0eD/YQVVQTDpGQAY1CkdFeH2/MppmgO23RkBSEwQzadR6P+jGom4W
M0dAWB+bpr5cdr+DJKeltbhHQBhgu5yK/Xk/NaiHVWU1SEDKPEUYFRF3v8tc
ME6LvEhAWcVror+tej+95QMFOUFJQCeFGeDl6Xu/xpSzNPe8SUBkzlRaHx15
P7N0K60rQ0pAXs4dyH6Der+3en+ecMBKQCxr1K8UoHg/oLGb2CtIS0DBM20t
z5J5v+S84tBuzUtACyeaTSofeT8/7gVCwklMQMGUB/eRnne/f1Dx+4vQTECV
jW+F3fF2P9bYuC5mTk1AlYciHmbPdb/A3CR/w81NQBjwpI3rwXQ//Tm2JQ==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    59.60752959477661}, {-0.094908374947385, 
                    0.09999999999945547}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "59.60752959477661`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAfgkCbDHzsD5UAJmZmZm5PxSyN707
GO8/ZvmDTupLuL/0W4XjgTMAQF4QNHb8BLc/0ix/ZfwRCEBtmJKErvm1v2lD
JsryyA9Agvn+hDn7tD8lNKjdphMUQPv5fz9burO/TXceHVj7F0A1bLH5m+ey
P5pB1qK7NhxAXOMaF+JDsb9iV/KMLi8gQJDsvgzDGK8/UybqK0EfIkAOQnCq
bZiuv9a4Au4sOSRArpjjuJauqj+144uTWi8mQFMuk96X/am/AmDAMacbKECD
ElYasPmpP+KfFfPMMSpA5+bHUoLMpr8deNuXNCQsQM57z77mgaY/6xPCX3VA
LkBncMNYxNGiv5QAKpBqKTBAMEQbNRGmnz9gQytiuyAxQG7xKXkJY6C/9ue8
xfgsMkC+/cIsTAeaP7rYBhtXJzNA7alClDdEmr9HK+EBojY0QMcE4bIdn5I/
iyYRZfxANUDeNePg2e+Jv/1t+bl3OTZAMneYNA80jT84F3Kg30Y3QAqVD/lg
l4C/oQyjeGhCOECCR5VIp9iBP8GqKc0AOTlAfkpqe2U/hr+qqkCzhUQ6QOrF
jXdHOnk/wfYPiys+O0Aub9Bldu99v6Kkb/S9TDxAQjDFB8S9YT86+yTaX1Y9
QDJIFh/J1VI/AJ6SsSJOPkAmPcqZitFGP4+ikBrSWj9ARBfYIje1aD+meaM6
0SpAQCsO7jdhc2C/X3YpJsGlQECQPyAm3nIRv/2jd1onK0FAruh+vZH/Zb+y
96EHnqdBQBo3l8BIOVc/THyU/YouQkAwYG8QHwFyv/0mY2yIrEJA6Ncp74Su
bj8JplyZDShDQOxxOO5EjWK/+lUeDwmuQ0BJaDuHtyJyPwIsvP0UK0RAnAD2
CksMbb/uMiI1l7JEQMr/buCeqXc/Ng6zKqE3RUByQfYonIV8v5UPIJm7s0VA
FBvdu5U0eD/YQVVQTDpGQAY1CkdFeH2/MppmgO23RkBSEwQzadR6P+jGom4W
M0dAWB+bpr5cdr+DJKeltbhHQBhgu5yK/Xk/NaiHVWU1SEDKPEUYFRF3v8tc
ME6LvEhAWcVror+tej+95QMFOUFJQCeFGeDl6Xu/xpSzNPe8SUBkzlRaHx15
P7N0K60rQ0pAXs4dyH6Der+3en+ecMBKQCxr1K8UoHg/oLGb2CtIS0DBM20t
z5J5v+S84tBuzUtACyeaTSofeT8/7gVCwklMQMGUB/eRnne/f1Dx+4vQTECV
jW+F3fF2P9bYuC5mTk1AlYciHmbPdb/A3CR/w81NQBjwpI3rwXQ//Tm2JQ==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    59.60752959477661}, {-0.094908374947385, 
                    0.09999999999945547}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "59.60752959477661`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->(
       "InterpolatingFunction[{{0., 59.6075}}, <>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.660833005811377*^9, 3.660835018027557*^9, 3.660835201534309*^9, 
   3.661192656677003*^9, 3.661192751653811*^9, 3.6611929553954906`*^9, {
   3.661193173089547*^9, 3.661193241899117*^9}, {3.661194310041231*^9, 
   3.661194327334326*^9}, 3.661195374982168*^9, 3.661293409718264*^9, 
   3.661293522011467*^9, {3.661293563401608*^9, 3.661293590558259*^9}, {
   3.661294020997212*^9, 3.661294042665042*^9}, {3.661294147098063*^9, 
   3.661294156193142*^9}, 3.661294213779451*^9, {3.661294252959532*^9, 
   3.661294289664345*^9}, 3.661294357678802*^9}]
}, Open  ]],

Cell["Plot the solution", "Text",
 CellChangeTimes->{{3.660833012250332*^9, 3.660833016253186*^9}, {
  3.660833109260655*^9, 3.660833112850033*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"plotpars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Quality\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Full"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", 
      RowBox[{"1", "/", "4"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"phi", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"Evaluate", "[", "plotpars", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.660833035223577*^9, 3.660833073597073*^9}, {
  3.6608352042179747`*^9, 3.660835205392108*^9}, {3.6611925280041103`*^9, 
  3.661192541677369*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUV3c8l28Xluy9d/bem6LuUxpaKjtJSH4yIgnZWdl7z6+99xbdlAYpI4RU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     "]]}},
  AspectRatio->NCache[
    Rational[1, 4], 0.25],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Full,
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->
   NCache[{{0, 6 10^Rational[1, 2] Pi}, {-0.0951251263164442, 
     0.09999999999920028}}, {{0, 59.60752959477661}, {-0.0951251263164442, 
     0.09999999999920028}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.660833076956625*^9, 3.66083501808286*^9, 3.6608352058026543`*^9, 
   3.66119265707733*^9, 3.661192759573637*^9, 3.661192955474865*^9, {
   3.661193173164143*^9, 3.661193241981011*^9}, {3.661194312855249*^9, 
   3.6611943274367228`*^9}, 3.661195375083688*^9, 3.6612934097732763`*^9, {
   3.661293567532983*^9, 3.661293594938696*^9}, 3.6612940240642443`*^9, 
   3.661294217311501*^9, {3.661294255076775*^9, 3.6612942924170723`*^9}, 
   3.661294357754938*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solve the Equations of Motion:
No dirve, big swing with damping\
\>", "Subsection",
 CellChangeTimes->{{3.661192395534131*^9, 3.661192407388399*^9}, {
  3.6611928211387577`*^9, 3.661192865383193*^9}, {3.661193284125386*^9, 
  3.661193284939232*^9}, {3.661193414953587*^9, 3.66119343431916*^9}, {
  3.6611935887812777`*^9, 3.6611936074181547`*^9}, {3.661194911278949*^9, 
  3.6611949154525537`*^9}, {3.661294547478236*^9, 3.6612945502011642`*^9}}],

Cell[TextData[{
 "Try different values of ",
 StyleBox["b", "Input"],
 " and note how the damping changes"
}], "Text",
 CellChangeTimes->{{3.661195014344286*^9, 3.661195070752245*^9}, {
  3.661195142223633*^9, 3.661195180564883*^9}, {3.661294555940527*^9, 
  3.661294574915996*^9}, {3.661340539662139*^9, 3.661340541091568*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"m", "\[Rule]", "1"}], ",", 
     RowBox[{"g", "\[Rule]", "10"}], ",", 
     RowBox[{"l", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "0.3"}], ",", 
     RowBox[{"ad", "\[Rule]", "0"}], ",", 
     RowBox[{"fd", "\[Rule]", "0.1"}], ",", 
     RowBox[{"phi0", "\[Rule]", 
      RowBox[{"\[Pi]", "/", "2"}]}], ",", 
     RowBox[{"v0", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{
    RowBox[{"5", " ", "2", 
     RowBox[{"\[Pi]", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"g", "/", "l"}], "]"}]}]}], "/.", "pars"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eom", ",", "incon"}], "}"}], "//.", "pars"}], ",", "dvars", 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
    RowBox[{"MaxStepSize", "\[Rule]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"10", " ", "fd"}], ")"}]}], "/.", "pars"}], "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"phi", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", 
   RowBox[{"Evaluate", "[", "plotpars", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.660832934883301*^9, 3.6608329811674843`*^9}, {
   3.66083518203434*^9, 3.660835186864388*^9}, {3.6611924588876343`*^9, 
   3.6611924687916613`*^9}, {3.661192715248855*^9, 3.6611927435998173`*^9}, {
   3.661192902039855*^9, 3.6611929408869123`*^9}, {3.661193088336308*^9, 
   3.661193090829599*^9}, {3.661193152562392*^9, 3.661193214374984*^9}, {
   3.661193313245545*^9, 3.661193378312942*^9}, {3.661193438504074*^9, 
   3.661193458723958*^9}, {3.661193521301283*^9, 3.661193521351925*^9}, {
   3.661193613244508*^9, 3.661193624555544*^9}, {3.661194226937459*^9, 
   3.6611942378027067`*^9}, {3.661194342886291*^9, 3.66119439561628*^9}, {
   3.66119447694575*^9, 3.6611945109544363`*^9}, {3.66119458211207*^9, 
   3.6611945894630413`*^9}, 3.66129430916492*^9, 3.6612943399215527`*^9, {
   3.661294495247138*^9, 3.661294525266803*^9}, {3.6612949884581003`*^9, 
   3.6612950364070883`*^9}, {3.661295223219771*^9, 3.661295257412889*^9}, {
   3.6612952913735857`*^9, 3.6612952915082083`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"phi", "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["InterpolatingFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA/mGtOpeZhj5RKkRU+yH5P2MhJX7S
usQ/00oZebgR9z/wz7GEAprVP9CCH576aPA/N3P/mP0L4D/JF8WOeY3bP0aC
GdyhMOU/VUakFigKzb+HReB83sTqP1Va8MzE3+q/Z/R90cr57z/JsFLTbxjz
v7wr5MEnz/I/nWDS5j+j9L8tH0MRPpT1P08Zw3BZlPG/boiNOqwp+D/4ydHW
/lTmv8hLrpLm9vo/rNHbBlorvL/yhLrEeJT9P+D8Q19nXNw/AUCAdm8SAED8
SoB092TrP5ZqDqKIdgFArqCguMsl8T8TUJK6zcICQFBkTq+2hfA/nGKB6vgq
BECTgSkhse7nPxlWjRWOjAVA16ePnLZ60j9+BI8tT9YGQDMp/JUcsci/79/7
XPY7CECqhyCCQUbkv0h2XnnJiQlA1OOHhZ3m67+uOSytgvMKQIni2HCisey/
CN4W3KVWDEApXa/xmynmv0o99/f0oQ1AGFdurWYb1r+YyUIrKgkPQOIjscpX
iLo/ZwjCpUUsEEDV+vDMI5LeP3wccTOr0BBAh3gdr+rW5j8Yx9XMA4MRQFI0
4kSQxOg/KE+1XHIpEkDSKQDI/5rkP75tSvjT3RJAA/Pt9zPP1T/O/G2R6o4T
QJ6ZJLl6E6O/UmkMIRc0FECzscsK8WDXv1xsYLw25xRADbnaD0JD47/aTC9O
bI4VQGm7NtoyO+W/0p2M3VYyFkD/dR7w9Cziv1CFn3g05BZAls/qEzCZ1L9C
Si0KKIoXQAteFOI9xpS/uqVwpw4+GEDtSjLgoMzSP6beLjsL5hhAWogui8bW
3z8MiHvMvIoZQPRgQqloM+I/+Md9aWE9GkADpf9PP3nfP1jl+vwb5BpALunN
O7wj0z8+mS2cyZgbQFb/R9pUN5M/n73uOCxKHEB3N4G9fMXPv3O/Ksyk7xxA
GTy6A5cW27/OVxxrEKMdQInUw/XdMN+/nc2IAJJKHkAZte0xhObav+azg5PI
7h5AROKlKUxm0L+1MDQy8qAfQHxjZEsV3ZK/e8Wv45gjIECa37FQ9HDJP989
IDSyfSBA+6uEE/Nf1z+A7lcDJtYgQBAt+VqtxNo/2w3NzaQoIUAu+OnCVxnX
P3r4HB4dgiFAEWvB49YXyj/TUappoNUhQD3tB5R6SIU/b3YSOx0wIkC0Zmpz
kFjIv0jTQYv0iCJAP/GAZqOq1L/bnq7W1tsiQLtRuGDX+da/sTX2p7I1I0Ac
rAt2+QPTv0E7e3SZiSNA4mU+7awAxb/VPcNUgt4jQCybphUoRHo/YUHhyA==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    9.934588265796101}, {-1.2898558632350963`, 
                    1.5707963267947387`}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "9.934588265796101`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA/mGtOpeZhj5RKkRU+yH5P2MhJX7S
usQ/00oZebgR9z/wz7GEAprVP9CCH576aPA/N3P/mP0L4D/JF8WOeY3bP0aC
GdyhMOU/VUakFigKzb+HReB83sTqP1Va8MzE3+q/Z/R90cr57z/JsFLTbxjz
v7wr5MEnz/I/nWDS5j+j9L8tH0MRPpT1P08Zw3BZlPG/boiNOqwp+D/4ydHW
/lTmv8hLrpLm9vo/rNHbBlorvL/yhLrEeJT9P+D8Q19nXNw/AUCAdm8SAED8
SoB092TrP5ZqDqKIdgFArqCguMsl8T8TUJK6zcICQFBkTq+2hfA/nGKB6vgq
BECTgSkhse7nPxlWjRWOjAVA16ePnLZ60j9+BI8tT9YGQDMp/JUcsci/79/7
XPY7CECqhyCCQUbkv0h2XnnJiQlA1OOHhZ3m67+uOSytgvMKQIni2HCisey/
CN4W3KVWDEApXa/xmynmv0o99/f0oQ1AGFdurWYb1r+YyUIrKgkPQOIjscpX
iLo/ZwjCpUUsEEDV+vDMI5LeP3wccTOr0BBAh3gdr+rW5j8Yx9XMA4MRQFI0
4kSQxOg/KE+1XHIpEkDSKQDI/5rkP75tSvjT3RJAA/Pt9zPP1T/O/G2R6o4T
QJ6ZJLl6E6O/UmkMIRc0FECzscsK8WDXv1xsYLw25xRADbnaD0JD47/aTC9O
bI4VQGm7NtoyO+W/0p2M3VYyFkD/dR7w9Cziv1CFn3g05BZAls/qEzCZ1L9C
Si0KKIoXQAteFOI9xpS/uqVwpw4+GEDtSjLgoMzSP6beLjsL5hhAWogui8bW
3z8MiHvMvIoZQPRgQqloM+I/+Md9aWE9GkADpf9PP3nfP1jl+vwb5BpALunN
O7wj0z8+mS2cyZgbQFb/R9pUN5M/n73uOCxKHEB3N4G9fMXPv3O/Ksyk7xxA
GTy6A5cW27/OVxxrEKMdQInUw/XdMN+/nc2IAJJKHkAZte0xhObav+azg5PI
7h5AROKlKUxm0L+1MDQy8qAfQHxjZEsV3ZK/e8Wv45gjIECa37FQ9HDJP989
IDSyfSBA+6uEE/Nf1z+A7lcDJtYgQBAt+VqtxNo/2w3NzaQoIUAu+OnCVxnX
P3r4HB4dgiFAEWvB49YXyj/TUappoNUhQD3tB5R6SIU/b3YSOx0wIkC0Zmpz
kFjIv0jTQYv0iCJAP/GAZqOq1L/bnq7W1tsiQLtRuGDX+da/sTX2p7I1I0Ac
rAt2+QPTv0E7e3SZiSNA4mU+7awAxb/VPcNUgt4jQCybphUoRHo/YUHhyA==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    9.934588265796101}, {-1.2898558632350963`, 
                    1.5707963267947387`}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "9.934588265796101`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->(
       "InterpolatingFunction[{{0., 9.93459}}, <>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, 
   3.661193627062294*^9, {3.661194232773589*^9, 3.661194238450338*^9}, {
   3.661194327833428*^9, 3.661194396382039*^9}, 3.6611945146420717`*^9, 
   3.661194590009468*^9, 3.661195375561357*^9, 3.661293410098922*^9, 
   3.661294357819447*^9, {3.661294497065905*^9, 3.661294525586348*^9}, 
   3.661294581939789*^9, {3.661294989397599*^9, 3.661295037147225*^9}, {
   3.661295225693164*^9, 3.66129525804569*^9}, 3.661295292737885*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUWXk81F8XtmXf95FhKBGSNYXcUyr9VJIlQiKFklYpUhRRkiyRpOwlkexL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     "]]}},
  AspectRatio->NCache[
    Rational[1, 4], 0.25],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Full,
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->
   NCache[{{0, 10^Rational[1, 2] Pi}, {-1.2947319573381477`, 
     1.570796326794663}}, {{0, 9.934588265796101}, {-1.2947319573381477`, 
     1.570796326794663}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, 
   3.661193627062294*^9, {3.661194232773589*^9, 3.661194238450338*^9}, {
   3.661194327833428*^9, 3.661194396382039*^9}, 3.6611945146420717`*^9, 
   3.661194590009468*^9, 3.661195375561357*^9, 3.661293410098922*^9, 
   3.661294357819447*^9, {3.661294497065905*^9, 3.661294525586348*^9}, 
   3.661294581939789*^9, {3.661294989397599*^9, 3.661295037147225*^9}, {
   3.661295225693164*^9, 3.66129525804569*^9}, 3.661295292807941*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solve the Equations of Motion:
Parametric Resonance\
\>", "Subsection",
 CellChangeTimes->{{3.661192395534131*^9, 3.661192407388399*^9}, {
  3.6611928211387577`*^9, 3.661192865383193*^9}, {3.661193284125386*^9, 
  3.661193284939232*^9}, {3.661193414953587*^9, 3.66119343431916*^9}, {
  3.6611935887812777`*^9, 3.6611936074181547`*^9}, {3.661193648939554*^9, 
  3.661193674487999*^9}, {3.6611937200810013`*^9, 3.661193742014243*^9}, {
  3.661294379850635*^9, 3.661294381856428*^9}, {3.661294417632258*^9, 
  3.6612944193343782`*^9}, {3.6612946316604223`*^9, 3.661294642378278*^9}}],

Cell[TextData[{
 "Try different values of ",
 StyleBox["fd", "Input"],
 " and note how the behavior changes at ",
 StyleBox["fd=2", "Input"]
}], "Text",
 CellChangeTimes->{{3.661195014344286*^9, 3.661195070752245*^9}, {
  3.6611952107756166`*^9, 3.661195256202414*^9}, {3.6612946900033007`*^9, 
  3.661294741511688*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"m", "\[Rule]", "1"}], ",", 
     RowBox[{"g", "\[Rule]", "10"}], ",", 
     RowBox[{"l", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "0.1"}], ",", 
     RowBox[{"ad", "\[Rule]", "0.1"}], ",", 
     RowBox[{"fd", "\[Rule]", "2"}], ",", 
     RowBox[{"phi0", "\[Rule]", "0.1"}], ",", 
     RowBox[{"v0", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"y1", "[", "t", "]"}], "/.", "pars"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{
    RowBox[{"20", " ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"g", "/", "l"}], "]"}]}], "/.", "pars"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eom", ",", "incon"}], "}"}], "//.", "pars"}], ",", "dvars", 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
    RowBox[{"MaxStepSize", "\[Rule]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"10", " ", "fd"}], ")"}]}], "/.", "pars"}], "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"phi", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"5", 
        RowBox[{"y1", "[", "t", "]"}]}], "/.", "pars"}], "]"}]}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", 
   RowBox[{"Evaluate", "[", "plotpars", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.660832934883301*^9, 3.6608329811674843`*^9}, {
   3.66083518203434*^9, 3.660835186864388*^9}, {3.6611924588876343`*^9, 
   3.6611924687916613`*^9}, {3.661192715248855*^9, 3.6611927435998173`*^9}, {
   3.661192902039855*^9, 3.6611929408869123`*^9}, {3.661193088336308*^9, 
   3.661193090829599*^9}, {3.661193152562392*^9, 3.661193214374984*^9}, {
   3.661193313245545*^9, 3.661193378312942*^9}, {3.661193438504074*^9, 
   3.661193458723958*^9}, {3.661193521301283*^9, 3.661193521351925*^9}, {
   3.661193613244508*^9, 3.661193624555544*^9}, {3.6611936799724407`*^9, 
   3.661193702626865*^9}, {3.661193745289027*^9, 3.661193777579794*^9}, {
   3.661293824830365*^9, 3.6612938427156067`*^9}, 3.6612943175792828`*^9, 
   3.661294349521381*^9, {3.661294645708147*^9, 3.661294670425048*^9}, {
   3.661294702451923*^9, 3.661294719908073*^9}, {3.661294750524214*^9, 
   3.661294830412313*^9}, {3.661295155433563*^9, 3.661295171957494*^9}, {
   3.6612965989963617`*^9, 3.661296689568124*^9}, {3.661296737688369*^9, 
   3.661296765705366*^9}, {3.661296829684482*^9, 3.661296832610485*^9}, {
   3.661296864883679*^9, 3.66129690280396*^9}, 3.661340607493169*^9}],

Cell[BoxData[
 RowBox[{"0.1`", " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", 
    SqrtBox["10"], " ", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, 
   3.661193627062294*^9, {3.661193685376652*^9, 3.661193703211871*^9}, {
   3.6611937470643682`*^9, 3.661193778333682*^9}, 3.661194328185762*^9, 
   3.661195376397057*^9, 3.6612934107239428`*^9, {3.661293830143725*^9, 
   3.6612938437616262`*^9}, 3.661294358150091*^9, {3.661294651782372*^9, 
   3.661294670997579*^9}, {3.661294703172014*^9, 3.661294721025676*^9}, {
   3.661294752283902*^9, 3.661294831519759*^9}, {3.661295155971706*^9, 
   3.6612951727861843`*^9}, {3.661296633279614*^9, 3.661296691370508*^9}, {
   3.661296744445942*^9, 3.661296766079486*^9}, 3.661296833984074*^9, {
   3.6612968684367647`*^9, 3.6612969040792828`*^9}, 3.661340609823916*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"phi", "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["InterpolatingFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA1try3Qb8sT555JiZmZm5P9il3vII
f/A/7I41TKcesr8+EmxapDABQCqln+ZRNas/5bzU8xGKCUAL3ffo9AmovxtI
qgLJ3BBA9sKHPiy+qD9uAyEHV00VQJw8n2tKKrC/bLTN5wtyGUByHgrnwPq0
PxU3McSO7x1AsU4XC36QvL8JJ1BuDSwhQPaGxAiRQME/Xa2i6GY6I0AOf+O3
mV/Fv4ec0GAndSVAtFNSH+A3wz+GhhlH+4knQI1IdZ+aksO/sDpoy1OUKUAV
f2qEcbrFP69Xkk0TyytA/U6Xa80dmb+Db9c95tstQKDBqNJGfpy/Fvj7FZAM
MEAwCkwAtJTVP4AdD1zvJTFAXBDReCnf479VwC9ZWCwyQERsB9eRsOA/lBc+
1fRIM0BKEs4Ohl7jvz7sWQibUjRAGFbpWPxi3j9TdWO6dHI1QLbKqOPbq+a/
feNvuxCNNkB85nr7ATnpPxLPiXO2lDdA+aXSE41W6L8Rb5Gqj7I4QOJr+XyX
5OQ/e4ymmHK9OUBLpVFzMIriv/qOvtUXwzpA1KdD69in4j/kRcSR8N47QM2h
pwoc/dW/OHrXBNPnPEAFWgzZlQfZP/di2PboBj5Ab4hAH5kHuL/LMNw3wSA/
QFvJnSJbNse/Bb72l9ETQEBeygCm0zDQP9k9dlNcokBAWsFrsame479jfHzq
aydBQJi2oBbtIeg/dy0EqdypQUBV9ZwsOsvrv8G4AidnN0JAnSf2UtvZ8D/A
AoiAdrtCQKQsLr5IhfK/9CaEmZ9KQ0A4N/SX2zbyP94JB45N0ENAP+YROmoP
8r9SXwuqXFNEQNDgidjvZvE//I6GhYXhRECAJWXM+O3nv1t9iDwzZkVAddvH
QcHA4T/vRQGz+vVFQFYGXqZ1krO/DoH7UCODRkDOCKiBrUHVv+J6fMrQBkdA
YNRyxj8M4D/sTnQDmJVHQGbj2WrpPOy/q+HyF+QaSEDhm7BjRm3wP/Xm8lOR
nUhAlEL03dBf8b90xmlPWCtJQO5Y4pbKh/M/qGRnJqSvSUBNUm+unCTzvxHd
27wJP0pAgQngPJtv8T8FyNF60MtKQGdr44DtMeu/rnFOFBxPS0B8sG4LzFvn
P431QW2B3UtAZHcaULGD1r8hOLyha2JMQMSQLXLjysg/6lStlW/yTECYAMlU
Yi7QPz7kH7HUf01AsqwDF+NS479HMhmovgNOQNCEhSMe/eU/hlqJXsKSTkCl
KYQMqlrvv3pBgPBKGE9A3PxV48Kt8D+57pJAbp9PQKF0plAOk/G/F4XbjQ==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    63.24555320336759}, {-1.1964384855138122`, 
                    1.2206521886742467`}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "63.24555320336759`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA1try3Qb8sT555JiZmZm5P9il3vII
f/A/7I41TKcesr8+EmxapDABQCqln+ZRNas/5bzU8xGKCUAL3ffo9AmovxtI
qgLJ3BBA9sKHPiy+qD9uAyEHV00VQJw8n2tKKrC/bLTN5wtyGUByHgrnwPq0
PxU3McSO7x1AsU4XC36QvL8JJ1BuDSwhQPaGxAiRQME/Xa2i6GY6I0AOf+O3
mV/Fv4ec0GAndSVAtFNSH+A3wz+GhhlH+4knQI1IdZ+aksO/sDpoy1OUKUAV
f2qEcbrFP69Xkk0TyytA/U6Xa80dmb+Db9c95tstQKDBqNJGfpy/Fvj7FZAM
MEAwCkwAtJTVP4AdD1zvJTFAXBDReCnf479VwC9ZWCwyQERsB9eRsOA/lBc+
1fRIM0BKEs4Ohl7jvz7sWQibUjRAGFbpWPxi3j9TdWO6dHI1QLbKqOPbq+a/
feNvuxCNNkB85nr7ATnpPxLPiXO2lDdA+aXSE41W6L8Rb5Gqj7I4QOJr+XyX
5OQ/e4ymmHK9OUBLpVFzMIriv/qOvtUXwzpA1KdD69in4j/kRcSR8N47QM2h
pwoc/dW/OHrXBNPnPEAFWgzZlQfZP/di2PboBj5Ab4hAH5kHuL/LMNw3wSA/
QFvJnSJbNse/Bb72l9ETQEBeygCm0zDQP9k9dlNcokBAWsFrsame479jfHzq
aydBQJi2oBbtIeg/dy0EqdypQUBV9ZwsOsvrv8G4AidnN0JAnSf2UtvZ8D/A
AoiAdrtCQKQsLr5IhfK/9CaEmZ9KQ0A4N/SX2zbyP94JB45N0ENAP+YROmoP
8r9SXwuqXFNEQNDgidjvZvE//I6GhYXhRECAJWXM+O3nv1t9iDwzZkVAddvH
QcHA4T/vRQGz+vVFQFYGXqZ1krO/DoH7UCODRkDOCKiBrUHVv+J6fMrQBkdA
YNRyxj8M4D/sTnQDmJVHQGbj2WrpPOy/q+HyF+QaSEDhm7BjRm3wP/Xm8lOR
nUhAlEL03dBf8b90xmlPWCtJQO5Y4pbKh/M/qGRnJqSvSUBNUm+unCTzvxHd
27wJP0pAgQngPJtv8T8FyNF60MtKQGdr44DtMeu/rnFOFBxPS0B8sG4LzFvn
P431QW2B3UtAZHcaULGD1r8hOLyha2JMQMSQLXLjysg/6lStlW/yTECYAMlU
Yi7QPz7kH7HUf01AsqwDF+NS479HMhmovgNOQNCEhSMe/eU/hlqJXsKSTkCl
KYQMqlrvv3pBgPBKGE9A3PxV48Kt8D+57pJAbp9PQKF0plAOk/G/F4XbjQ==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    63.24555320336759}, {-1.1964384855138122`, 
                    1.2206521886742467`}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "63.24555320336759`"}], "}"}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->(
       "InterpolatingFunction[{{0., 63.2456}}, <>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, 
   3.661193627062294*^9, {3.661193685376652*^9, 3.661193703211871*^9}, {
   3.6611937470643682`*^9, 3.661193778333682*^9}, 3.661194328185762*^9, 
   3.661195376397057*^9, 3.6612934107239428`*^9, {3.661293830143725*^9, 
   3.6612938437616262`*^9}, 3.661294358150091*^9, {3.661294651782372*^9, 
   3.661294670997579*^9}, {3.661294703172014*^9, 3.661294721025676*^9}, {
   3.661294752283902*^9, 3.661294831519759*^9}, {3.661295155971706*^9, 
   3.6612951727861843`*^9}, {3.661296633279614*^9, 3.661296691370508*^9}, {
   3.661296744445942*^9, 3.661296766079486*^9}, 3.661296833984074*^9, {
   3.6612968684367647`*^9, 3.6612969040792828`*^9}, 3.661340609883603*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUV3c80O8TR7Jlj2TvvXfqOQ0NGVEoiST52kpRIYmGKCNb9t5krycjeyVZ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     "]]}, 
   {RGBColor[0.985248, 0.676238, 0.0398315], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUmHc8198XxxEie4TsvfcmdQ8iZSQrlaK+kmSWpCWEVJRdUSSKlJQyk2uP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     "]]}},
  AspectRatio->NCache[
    Rational[1, 4], 0.25],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Full,
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->
   NCache[{{0, 20 10^Rational[1, 2]}, {-1.430810957485762, 
     1.5660605146167357`}}, {{0, 63.24555320336759}, {-1.430810957485762, 
     1.5660605146167357`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, 
   3.661193627062294*^9, {3.661193685376652*^9, 3.661193703211871*^9}, {
   3.6611937470643682`*^9, 3.661193778333682*^9}, 3.661194328185762*^9, 
   3.661195376397057*^9, 3.6612934107239428`*^9, {3.661293830143725*^9, 
   3.6612938437616262`*^9}, 3.661294358150091*^9, {3.661294651782372*^9, 
   3.661294670997579*^9}, {3.661294703172014*^9, 3.661294721025676*^9}, {
   3.661294752283902*^9, 3.661294831519759*^9}, {3.661295155971706*^9, 
   3.6612951727861843`*^9}, {3.661296633279614*^9, 3.661296691370508*^9}, {
   3.661296744445942*^9, 3.661296766079486*^9}, 3.661296833984074*^9, {
   3.6612968684367647`*^9, 3.6612969040792828`*^9}, 3.6613406099903173`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solve the Equations of Motion:
High Frequency Drive - strange\
\>", "Subsection",
 CellChangeTimes->{{3.661192395534131*^9, 3.661192407388399*^9}, {
  3.6611928211387577`*^9, 3.661192865383193*^9}, {3.661193284125386*^9, 
  3.661193284939232*^9}, {3.661193414953587*^9, 3.66119343431916*^9}, {
  3.6611935887812777`*^9, 3.6611936074181547`*^9}, {3.661193648939554*^9, 
  3.661193674487999*^9}, {3.6611937200810013`*^9, 3.661193723822339*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"m", "\[Rule]", "1"}], ",", 
     RowBox[{"g", "\[Rule]", "10"}], ",", 
     RowBox[{"l", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "0.1"}], ",", 
     RowBox[{"ad", "\[Rule]", "0.1"}], ",", 
     RowBox[{"fd", "\[Rule]", "14"}], ",", 
     RowBox[{"phi0", "\[Rule]", 
      RowBox[{"\[Pi]", "+", "0.1"}]}], ",", 
     RowBox[{"v0", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{
    RowBox[{"5", " ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"g", "/", "l"}], "]"}]}], "/.", "pars"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eom", ",", "incon"}], "}"}], "//.", "pars"}], ",", "dvars", 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
    RowBox[{"MaxStepSize", "\[Rule]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"10", " ", "fd"}], ")"}]}], "/.", "pars"}], "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"phi", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"Evaluate", "[", "plotpars", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.660832934883301*^9, 3.6608329811674843`*^9}, {
   3.66083518203434*^9, 3.660835186864388*^9}, {3.6611924588876343`*^9, 
   3.6611924687916613`*^9}, {3.661192715248855*^9, 3.6611927435998173`*^9}, {
   3.661192902039855*^9, 3.6611929408869123`*^9}, {3.661193088336308*^9, 
   3.661193090829599*^9}, {3.661193152562392*^9, 3.661193214374984*^9}, {
   3.661193313245545*^9, 3.661193378312942*^9}, {3.661193438504074*^9, 
   3.661193458723958*^9}, {3.661193521301283*^9, 3.661193521351925*^9}, {
   3.661193613244508*^9, 3.661193624555544*^9}, {3.6611936799724407`*^9, 
   3.661193702626865*^9}, {3.661293664650103*^9, 3.661293811531927*^9}, 
   3.661294314115024*^9, 3.66129434487486*^9, {3.661294440651733*^9, 
   3.661294441589591*^9}, {3.661295121013081*^9, 3.6612951210679207`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"phi", "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["InterpolatingFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA1try3Qb8kT5e+hAhyO4JQNil3vII
f9A/zlMIiw0MCUA+EmxapDDhPye65T1wLwhA5bzU8xGK6T+7d8/unVYHQBtI
qgLJ3PA/ucmFZ+soBkBuAyEHV031PxBqfvAB2gRAbLTN5wty+T8cxnwiLCID
QBU3McSO7/0/J6fmqGJqAEAJJ1BuDSwBQECj5PJAqvY/Xa2i6GY6A0BbhGHM
mO7QP4ec0GAndQVAXZTuxZQa9b+GhhlH+4kHQDm3xXAglf+/sDpoy1OUCUCF
PP7BZTMAwK9Xkk0TywtAiP/6jgx/+7+Db9c95tsNQEcSyrUD+Om/Fvj7FZAM
EEAdIRwpgmvjP4AdD1zvJRFAmL8314cF+D9VwC9ZWCwSQHakBHhbG/w/lBc+
1fRIE0D07+B/Sm31Pz7sWQibUhRARvbVNdmdxT9TdWO6dHIVQH5lJPz/l/S/
feNvuxCNFkDZpAFBgHD7vxLPiXO2lBdAG7A/UHhu9b8Rb5Gqj7IYQHxZN3Ch
PsC/e4ymmHK9GUDmFFp1UvXvP/qOvtUXwxpAwlsd/i2r9j/kRcSR8N4bQBZ1
pqmdRvE/OHrXBNPnHECvm36i9ouRP/di2PboBh5AzfamZzhr87/LMNw3wSAf
QB3JPQuINPe/Bb72l9ETIEARMbbaXUbpv9k9dlNcoiBAHWfjutTd4z9jfHzq
aychQEWhrsW/uPM/dy0EqdypIUB3L5Q6Ja7wP8G4AidnNyJAdAy70gl6uz/A
AoiAdrsiQHstGWqpSe6/9CaEmZ9KI0Aqfr7k36/zv94JB45N0CNAPjNSZSHn
479SXwuqXFMkQFl7pplZo+M//I6GhYXhJEBLhTgYBz/zP1t9iDwzZiVAoMUv
WIDr6D/vRQGz+vUlQLHw7NAkkdK/DoH7UCODJkAnjTwZ4Jrvv+J6fMrQBidA
DmGPHx6P67/sTnQDmJUnQJpJO4anSLI/q+HyF+QaKECnkPxPhhzvP/Xm8lOR
nShAUjFdJS+/8D90xmlPWCspQDzbRVHWCb0/qGRnJqSvKUDhWdUIP7jpvxHd
27wJPypAq/JWoLJ27b8FyNF60MsqQOaTnlSHdsG/rnFOFBxPK0Dj9plLXFHl
P431QW2B3StAwd1fobrj6j8hOLyha2IsQEk4mybdu88/6lStlW/yLEBX3AmO
DPPmvz7kH7HUfy1AxSE3CrKX7L9HMhmovgMuQAxdKLCWdMm/hlqJXsKSLkC6
BlUNy+joP3pBgPBKGC9AkIM5XJvM6j+57pJAbp8vQNAnb9Eisb0/l73KLQ==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    15.811388300841898`}, {-2.0250964313232225`, 
                    3.241592653589847}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "15.811388300841898`"}], "}"}], "}"}],
                     "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA1try3Qb8kT5e+hAhyO4JQNil3vII
f9A/zlMIiw0MCUA+EmxapDDhPye65T1wLwhA5bzU8xGK6T+7d8/unVYHQBtI
qgLJ3PA/ucmFZ+soBkBuAyEHV031PxBqfvAB2gRAbLTN5wty+T8cxnwiLCID
QBU3McSO7/0/J6fmqGJqAEAJJ1BuDSwBQECj5PJAqvY/Xa2i6GY6A0BbhGHM
mO7QP4ec0GAndQVAXZTuxZQa9b+GhhlH+4kHQDm3xXAglf+/sDpoy1OUCUCF
PP7BZTMAwK9Xkk0TywtAiP/6jgx/+7+Db9c95tsNQEcSyrUD+Om/Fvj7FZAM
EEAdIRwpgmvjP4AdD1zvJRFAmL8314cF+D9VwC9ZWCwSQHakBHhbG/w/lBc+
1fRIE0D07+B/Sm31Pz7sWQibUhRARvbVNdmdxT9TdWO6dHIVQH5lJPz/l/S/
feNvuxCNFkDZpAFBgHD7vxLPiXO2lBdAG7A/UHhu9b8Rb5Gqj7IYQHxZN3Ch
PsC/e4ymmHK9GUDmFFp1UvXvP/qOvtUXwxpAwlsd/i2r9j/kRcSR8N4bQBZ1
pqmdRvE/OHrXBNPnHECvm36i9ouRP/di2PboBh5AzfamZzhr87/LMNw3wSAf
QB3JPQuINPe/Bb72l9ETIEARMbbaXUbpv9k9dlNcoiBAHWfjutTd4z9jfHzq
aychQEWhrsW/uPM/dy0EqdypIUB3L5Q6Ja7wP8G4AidnNyJAdAy70gl6uz/A
AoiAdrsiQHstGWqpSe6/9CaEmZ9KI0Aqfr7k36/zv94JB45N0CNAPjNSZSHn
479SXwuqXFMkQFl7pplZo+M//I6GhYXhJEBLhTgYBz/zP1t9iDwzZiVAoMUv
WIDr6D/vRQGz+vUlQLHw7NAkkdK/DoH7UCODJkAnjTwZ4Jrvv+J6fMrQBidA
DmGPHx6P67/sTnQDmJUnQJpJO4anSLI/q+HyF+QaKECnkPxPhhzvP/Xm8lOR
nShAUjFdJS+/8D90xmlPWCspQDzbRVHWCb0/qGRnJqSvKUDhWdUIP7jpvxHd
27wJPypAq/JWoLJ27b8FyNF60MsqQOaTnlSHdsG/rnFOFBxPK0Dj9plLXFHl
P431QW2B3StAwd1fobrj6j8hOLyha2IsQEk4mybdu88/6lStlW/yLEBX3AmO
DPPmvz7kH7HUfy1AxSE3CrKX7L9HMhmovgMuQAxdKLCWdMm/hlqJXsKSLkC6
BlUNy+joP3pBgPBKGC9AkIM5XJvM6j+57pJAbp8vQNAnb9Eisb0/l73KLQ==

                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 0}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 
                    15.811388300841898`}, {-2.0250964313232225`, 
                    3.241592653589847}}, PlotRangeClipping -> True, 
                   PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "15.811388300841898`"}], "}"}], "}"}],
                     "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->(
       "InterpolatingFunction[{{0., 15.8114}}, <>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, 
   3.661193627062294*^9, {3.661193685376652*^9, 3.661193703211871*^9}, 
   3.6611943280216017`*^9, 3.661195376158166*^9, 3.661293410290354*^9, {
   3.661293668814188*^9, 3.6612938121630297`*^9}, 3.661294357982706*^9, 
   3.6612944428081284`*^9, 3.661295121756591*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUWXk4FF4XHtuMfRnLINpsqRRFInWPtp8SIZWQ7ImEEK0osqSEqCRLtkKR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     "]]}},
  AspectRatio->NCache[
    Rational[1, 4], 0.25],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Full,
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->
   NCache[{{0, 5 10^Rational[1, 2]}, {-2.0884481725501733`, 
     3.241592653589876}}, {{0, 15.811388300841898`}, {-2.0884481725501733`, 
     3.241592653589876}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, 
   3.661193627062294*^9, {3.661193685376652*^9, 3.661193703211871*^9}, 
   3.6611943280216017`*^9, 3.661195376158166*^9, 3.661293410290354*^9, {
   3.661293668814188*^9, 3.6612938121630297`*^9}, 3.661294357982706*^9, 
   3.6612944428081284`*^9, 3.661295121841416*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solve the Equations of Motion:
Higher Frequency Drive - Kapitza\
\>", "Subsection",
 CellChangeTimes->{{3.661192395534131*^9, 3.661192407388399*^9}, {
  3.6611928211387577`*^9, 3.661192865383193*^9}, {3.661193284125386*^9, 
  3.661193284939232*^9}, {3.661193414953587*^9, 3.66119343431916*^9}, {
  3.6611935887812777`*^9, 3.6611936074181547`*^9}, {3.661193648939554*^9, 
  3.661193674487999*^9}, {3.6611937200810013`*^9, 3.661193742014243*^9}, {
  3.661294379850635*^9, 3.661294381856428*^9}, {3.661294417632258*^9, 
  3.6612944193343782`*^9}}],

Cell[TextData[{
 "Try different values of ",
 StyleBox["fd", "Input"],
 " and note how the stability and frequency of the \[Pi] oscillations change"
}], "Text",
 CellChangeTimes->{{3.661195014344286*^9, 3.661195070752245*^9}, {
  3.6611952107756166`*^9, 3.661195256202414*^9}, {3.661295058850213*^9, 
  3.661295059328158*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pars", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"m", "\[Rule]", "1"}], ",", 
     RowBox[{"g", "\[Rule]", "10"}], ",", 
     RowBox[{"l", "\[Rule]", "1"}], ",", 
     RowBox[{"b", "\[Rule]", "0.1"}], ",", 
     RowBox[{"ad", "\[Rule]", "0.1"}], ",", 
     RowBox[{"fd", "\[Rule]", "16"}], ",", 
     RowBox[{"phi0", "\[Rule]", 
      RowBox[{"\[Pi]", "-", "0.1"}]}], ",", 
     RowBox[{"v0", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{
    RowBox[{"5", " ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"g", "/", "l"}], "]"}]}], "/.", "pars"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eom", ",", "incon"}], "}"}], "//.", "pars"}], ",", "dvars", 
    ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
    RowBox[{"MaxStepSize", "\[Rule]", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"10", " ", "fd"}], ")"}]}], "/.", "pars"}], "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"phi", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", 
   RowBox[{"Evaluate", "[", "plotpars", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.660832934883301*^9, 3.6608329811674843`*^9}, {
   3.66083518203434*^9, 3.660835186864388*^9}, {3.6611924588876343`*^9, 
   3.6611924687916613`*^9}, {3.661192715248855*^9, 3.6611927435998173`*^9}, {
   3.661192902039855*^9, 3.6611929408869123`*^9}, {3.661193088336308*^9, 
   3.661193090829599*^9}, {3.661193152562392*^9, 3.661193214374984*^9}, {
   3.661193313245545*^9, 3.661193378312942*^9}, {3.661193438504074*^9, 
   3.661193458723958*^9}, {3.661193521301283*^9, 3.661193521351925*^9}, {
   3.661193613244508*^9, 3.661193624555544*^9}, {3.6611936799724407`*^9, 
   3.661193702626865*^9}, {3.661193745289027*^9, 3.661193777579794*^9}, {
   3.661293824830365*^9, 3.6612938427156067`*^9}, 3.6612943175792828`*^9, 
   3.661294349521381*^9, {3.661295063268121*^9, 3.661295092541916*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"phi", "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["InterpolatingFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwVkvs71QcAh106vpdDwuEg4rjnrp7h8XDOxzYTHrejszCbSxvLdXPdg1wj
sjTG0lM9pvBIyLaaRNRirWwPzeWYOC5zz4PpHOKwZj+8z/sHvC8nIoH/mZyM
jIzzPv97ZGxjQmG3jPs8NO28tYDEaJ1og8we4BVPjvB3YilwVWODa22nef+I
VxJ7q2jMdQ69VrmwxBMwq71ofyYOn2iUeza+zpPyUzPF9UzEy3OIU94SnqLu
NduoBCZi7/6xwEzc5smpFzmXGDGh7mDXU7q2x/NpYWzfbqZBmfrFK1nKQtva
f2exjcLHzTcWI53kER32/WZ4A4nz1wbCTFMYcDw4svVkmEBhoZa7tJjAh3w/
L09/Aq1On/cFVFB4Gl5tx1IlcOdUubdaHxNJBS5Jz8QKyE8Qusy/VILWoqxA
142Axhup+jeKh2Cw3ZF7bItAjq5yyJqxCtJ+j2vUlJIQPLIJCrRURe+liZra
fgoVbO6w+IQaWiVbRR45NLgrQeRVPguqX7j63tumEZBy+kFyojre2Kpry4Qz
cfbvhI5DFzWwJFDGGWUmVPuLk36uYGMrr1s2N4WGSkJZ46UfNZHVfU+ZfZlC
xtf1VYkPtdCa4xTaLSSxU9o1zH6ijaJXCubXzUjMuvWUrYsOw6zlyKpOLAHH
dOGBwQUd5Gj0z5ToENiKGN1cVDiCmx1hzVPeBPpsxx0e6+shb1rx/R0RAUbX
5uUXavrobbF66hNP4i+X1ICQG/qI6Ekn7htTOJ2ZuRxjykFVbNbm+gyFNKsD
t8ZvcVBTqpvNzqbx+L6caZSDASr36HeqZmg8kivKSe0wgIrQ67v2SRpik3NX
qj0N4XzF7z1RNA0RRZR6DxjCzn4pyGeTAj+U2RgSYIRB3X/ZnEgKu6WFBQXT
RsgY/Ookq5XER2eLnI9HGuN4lqyoSInEmpvsTzsSY1SUL5f7NxE4mCv1M8w3
gXLa6nhAB4GZ9MznAwqm8GiLsDGYI7DikyxfVWmKpnrWzTh7ErenN9iz2mZQ
G5UJ//MBCcn8RkDZdTM0ZViFjQZTSP71jG+gxVHczWNcMNij0PBplEntnaNw
F74bwwjd7zPxspPimSPaOtNDGk6D8duL9IE+c5jHeAg5AhotX/qwdHwtIDGe
6nZk0bgocY3LnbDAZNfWmKCOAsexsyYmwhLzDxe8ipkUlk82VyZsWKIudbH9
bT4J7qzeD0PZVpizEr/etSbhfkyroUveGkN63JSSt/t/Bxd/8ku5Na5qt3lO
TxFId81Z99S0gYv0VaO9Lon21XLEV9tg7IPYQI1vSfwHCCmXjQ==
                    
                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 2.8000000000000003`}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 15.811388300841898`}, {
                    2.869524860682469, 3.456521007882086}}, PlotRangeClipping -> 
                   True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "15.811388300841898`"}], "}"}], "}"}],
                     "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{{}, {}, {
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.21099, 0.531208, 0.953188], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwVkvs71QcAh106vpdDwuEg4rjnrp7h8XDOxzYTHrejszCbSxvLdXPdg1wj
sjTG0lM9pvBIyLaaRNRirWwPzeWYOC5zz4PpHOKwZj+8z/sHvC8nIoH/mZyM
jIzzPv97ZGxjQmG3jPs8NO28tYDEaJ1og8we4BVPjvB3YilwVWODa22nef+I
VxJ7q2jMdQ69VrmwxBMwq71ofyYOn2iUeza+zpPyUzPF9UzEy3OIU94SnqLu
NduoBCZi7/6xwEzc5smpFzmXGDGh7mDXU7q2x/NpYWzfbqZBmfrFK1nKQtva
f2exjcLHzTcWI53kER32/WZ4A4nz1wbCTFMYcDw4svVkmEBhoZa7tJjAh3w/
L09/Aq1On/cFVFB4Gl5tx1IlcOdUubdaHxNJBS5Jz8QKyE8Qusy/VILWoqxA
142Axhup+jeKh2Cw3ZF7bItAjq5yyJqxCtJ+j2vUlJIQPLIJCrRURe+liZra
fgoVbO6w+IQaWiVbRR45NLgrQeRVPguqX7j63tumEZBy+kFyojre2Kpry4Qz
cfbvhI5DFzWwJFDGGWUmVPuLk36uYGMrr1s2N4WGSkJZ46UfNZHVfU+ZfZlC
xtf1VYkPtdCa4xTaLSSxU9o1zH6ijaJXCubXzUjMuvWUrYsOw6zlyKpOLAHH
dOGBwQUd5Gj0z5ToENiKGN1cVDiCmx1hzVPeBPpsxx0e6+shb1rx/R0RAUbX
5uUXavrobbF66hNP4i+X1ICQG/qI6Ekn7htTOJ2ZuRxjykFVbNbm+gyFNKsD
t8ZvcVBTqpvNzqbx+L6caZSDASr36HeqZmg8kivKSe0wgIrQ67v2SRpik3NX
qj0N4XzF7z1RNA0RRZR6DxjCzn4pyGeTAj+U2RgSYIRB3X/ZnEgKu6WFBQXT
RsgY/Ookq5XER2eLnI9HGuN4lqyoSInEmpvsTzsSY1SUL5f7NxE4mCv1M8w3
gXLa6nhAB4GZ9MznAwqm8GiLsDGYI7DikyxfVWmKpnrWzTh7ErenN9iz2mZQ
G5UJ//MBCcn8RkDZdTM0ZViFjQZTSP71jG+gxVHczWNcMNij0PBplEntnaNw
F74bwwjd7zPxspPimSPaOtNDGk6D8duL9IE+c5jHeAg5AhotX/qwdHwtIDGe
6nZk0bgocY3LnbDAZNfWmKCOAsexsyYmwhLzDxe8ipkUlk82VyZsWKIudbH9
bT4J7qzeD0PZVpizEr/etSbhfkyroUveGkN63JSSt/t/Bxd/8ku5Na5qt3lO
TxFId81Z99S0gYv0VaO9Lon21XLEV9tg7IPYQI1vSfwHCCmXjQ==
                    
                    "]]}}}, {
                  DisplayFunction -> Identity, AspectRatio -> 1, 
                   Axes -> {False, False}, AxesLabel -> {None, None}, 
                   AxesOrigin -> {0, 2.8000000000000003`}, 
                   BaseStyle -> {FontFamily -> "Georgia"}, DisplayFunction :> 
                   Identity, Frame -> {{True, True}, {True, True}}, 
                   FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                   Directive[
                    Opacity[0.5], 
                    Thickness[Tiny], 
                    RGBColor[0.368417, 0.506779, 0.709798]], 
                   FrameTicks -> {{None, None}, {None, None}}, 
                   GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}], 
                   LabelStyle -> {FontFamily -> "Georgia"}, 
                   Method -> {
                    "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> 
                    None}, PlotRange -> {{0., 15.811388300841898`}, {
                    2.869524860682469, 3.456521007882086}}, PlotRangeClipping -> 
                   True, PlotRangePadding -> {{
                    Scaled[0.1], 
                    Scaled[0.1]}, {
                    Scaled[0.1], 
                    Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "15.811388300841898`"}], "}"}], "}"}],
                     "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->(
       "InterpolatingFunction[{{0., 15.8114}}, <>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, 
   3.661193627062294*^9, {3.661193685376652*^9, 3.661193703211871*^9}, {
   3.6611937470643682`*^9, 3.661193778333682*^9}, 3.661194328185762*^9, 
   3.661195376397057*^9, 3.6612934107239428`*^9, {3.661293830143725*^9, 
   3.6612938437616262`*^9}, 3.661294358150091*^9, {3.6612950652636757`*^9, 
   3.661295093244618*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.21099, 0.531208, 0.953188], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUW3k4VV8URbzhXuPDe5KhMmRoJBWps4UGIpESGRNSQqlExjIkIlOiDCkK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     "]]}},
  AspectRatio->NCache[
    Rational[1, 4], 0.25],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 2.82},
  BaseStyle->{FontFamily -> "Georgia"},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Full,
  LabelStyle->{FontFamily -> "Georgia"},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->
   NCache[{{0, 5 10^Rational[1, 2]}, {2.8250451735588, 3.494820794702986}}, {{
     0, 15.811388300841898`}, {2.8250451735588, 3.494820794702986}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.661193334484762*^9, 3.661193378618277*^9}, {
   3.661193444818667*^9, 3.661193459327108*^9}, 3.6611935225401793`*^9, 
   3.661193627062294*^9, {3.661193685376652*^9, 3.661193703211871*^9}, {
   3.6611937470643682`*^9, 3.661193778333682*^9}, 3.661194328185762*^9, 
   3.661195376397057*^9, 3.6612934107239428`*^9, {3.661293830143725*^9, 
   3.6612938437616262`*^9}, 3.661294358150091*^9, {3.6612950652636757`*^9, 
   3.661295093317272*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1225, 700},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (June 27, \
2014)",
StyleDefinitions->FrontEnd`FileName[{"SlideShow"}, "Sapphire.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 210, 3, 174, "Section"],
Cell[CellGroupData[{
Cell[815, 29, 110, 1, 106, "Subsection"],
Cell[928, 32, 511, 11, 123, "Text"],
Cell[CellGroupData[{
Cell[1464, 47, 1272, 39, 119, "Input"],
Cell[2739, 88, 566, 13, 43, "Output"],
Cell[3308, 103, 1083, 28, 64, "Output"]
}, Open  ]],
Cell[4406, 134, 238, 3, 59, "Text"],
Cell[CellGroupData[{
Cell[4669, 141, 1219, 37, 119, "Input"],
Cell[5891, 180, 978, 27, 43, "Output"],
Cell[6872, 209, 706, 18, 43, "Output"],
Cell[7581, 229, 1033, 27, 43, "Output"],
Cell[8617, 258, 987, 27, 43, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9653, 291, 296, 4, 106, "Subsection"],
Cell[9952, 297, 210, 3, 59, "Text"],
Cell[10165, 302, 237, 5, 43, "Input"],
Cell[10405, 309, 174, 2, 59, "Text"],
Cell[CellGroupData[{
Cell[10604, 315, 1182, 35, 94, "Input"],
Cell[11789, 352, 927, 28, 131, "Output"]
}, Open  ]],
Cell[12731, 383, 103, 1, 59, "Text"],
Cell[12837, 386, 1388, 31, 94, "Input"],
Cell[14228, 419, 99, 1, 59, "Text"],
Cell[CellGroupData[{
Cell[14352, 424, 771, 20, 69, "Input"],
Cell[15126, 446, 12219, 238, 72, "Output"]
}, Open  ]],
Cell[27360, 687, 148, 2, 59, "Text"],
Cell[CellGroupData[{
Cell[27533, 693, 768, 19, 94, "Input"],
Cell[28304, 714, 53054, 884, 219, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[81407, 1604, 456, 8, 150, "Subsection"],
Cell[81866, 1614, 328, 7, 59, "Text"],
Cell[CellGroupData[{
Cell[82219, 1625, 2550, 61, 194, "Input"],
Cell[84772, 1688, 12223, 237, 72, "Output"],
Cell[96998, 1927, 25974, 438, 219, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[123021, 2371, 590, 10, 150, "Subsection"],
Cell[123614, 2383, 320, 8, 59, "Text"],
Cell[CellGroupData[{
Cell[123959, 2395, 2917, 70, 194, "Input"],
Cell[126879, 2467, 934, 15, 52, "Output"],
Cell[127816, 2484, 12454, 240, 72, "Output"],
Cell[140273, 2726, 113564, 1875, 271, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[253886, 4607, 452, 8, 150, "Subsection"],
Cell[CellGroupData[{
Cell[254363, 4619, 2260, 56, 144, "Input"],
Cell[256626, 4677, 12062, 235, 72, "Output"],
Cell[268691, 4914, 57679, 959, 221, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[326419, 5879, 554, 10, 150, "Subsection"],
Cell[326976, 5891, 326, 7, 91, "Text"],
Cell[CellGroupData[{
Cell[327327, 5902, 2263, 56, 169, "Input"],
Cell[329593, 5960, 12036, 230, 72, "Output"],
Cell[341632, 6192, 55532, 923, 237, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
